@@ -10,7 +10,7 @@ class KActionCollection;
 class KrBookmark: public KAction {
 	Q_OBJECT
 public:
-	KrBookmark(QString name, KURL url, KActionCollection *parent);
+	KrBookmark(QString name, KURL url, KActionCollection *parent, QString icon = "");
 	KrBookmark(QString name); // creates a folder
 	// text() and setText() to change the name of the bookmark
 	// icon() and setIcon() to change icons (by name)
@@ -19,8 +19,12 @@ public:
 	inline bool isFolder() const { return _folder; }
 	inline bool isSeparator() const { return _separator; }
 	QPtrList<KrBookmark>& children() { return _children; }
+
+	static KrBookmark* getExistingBookmark(QString name, KActionCollection *collection);	
 	// ----- special bookmarks
 	static KrBookmark* devices(KActionCollection *collection);
+	static KrBookmark* virt(KActionCollection *collection);
+	static KrBookmark* lan(KActionCollection *collection);
 	static KrBookmark* separator();
 
 signals:
