@@ -36,6 +36,7 @@
 #include <kanimwidget.h>
 #include <kurlrequesterdlg.h>
 #include <kdatepicker.h>
+#include <kdialogbase.h>
 // QT includes
 #include <qlineedit.h>
 #include <qlayout.h>
@@ -47,37 +48,33 @@
 #include <qsemimodal.h>
 #include <qcheckbox.h>
 
-// the most basic dialog in krusader.
-class KRDialog : public KDialog {
-	Q_OBJECT
+/** \class KChooseDir
+ * Used for asking the user for a folder.
+ * example:
+ * \code
+ * KURL u = KChooseDir::getDir("target folder", "/suggested/path", ACTIVE_PANEL->virtualPath());
+ * if (u.isEmpty()) { 
+ *   // user canceled (either by pressing cancel, or esc
+ * } else {
+ *   // do you thing here: you've got a safe url to use
+ * }
+ * \endcode
+ */
+class KChooseDir {
 public:
-	KRDialog(QWidget *parent = 0, QString text = 0,bool modal=true, bool roomForIcon=false);
-
-protected:
-	QGridLayout *layout;		
-	QLabel 			*message;
-};
-
-class KChooseDir : KURLRequesterDlg {
-	Q_OBJECT	
-public:
-	KChooseDir(QWidget *parent, QString text,QString url);
-public slots:
-	void result();
-public:
-	static QString dest;
-};
-
-class KRAbout : public KRDialog {
-  Q_OBJECT
-public:
-  KRAbout();
+	/**
+	 * \param text - description of the info requested from the user
+	 * \param url - a suggested url to appear in the box as a default choice
+	 * \param cwd - a path which is the current working directory (usually ACTIVE_PANEL->virtualPath()).
+	 *              this is used for completion of partial urls
+	 */
+	static KURL getDir(QString text,const KURL& url, const KURL& cwd);
 };
 
 class KRGetDate : public KDialog {
   Q_OBJECT
 public:
-  KRGetDate(QDate date=QDate::currentDate());
+  KRGetDate(QDate date=QDate::currentDate(), QWidget *parent = 0, const char *name = 0);
   QDate getDate();
 
 private slots:
@@ -88,4 +85,20 @@ private:
   QDate chosenDate, originalDate;
 };
 
+class QCheckbox;
+
+class UserSelectionModeDlg: public KDialogBase {
+  Q_OBJECT
+public:
+	static int createCustomMode(QWidget *parent);
+	~UserSelectionModeDlg();
+	
+protected:
+	UserSelectionModeDlg(QWidget *parent);
+	QCheckBox *qtSelection, *leftButtonSelects, *leftButtonPreserves, *shiftCtrlLeftSelects;
+	QCheckBox *rightButtonSelects, *rightButtonPreserves, *shiftCtrlRightSelects, *spaceMovesDown;
+	QCheckBox *insertMovesDown, *spaceCalcSpace, *contextMenuImmediate;
+};
+
+
 #endif
