@@ -31,7 +31,7 @@
 #include "krpleasewait.h"
 #include <qtimer.h>
 #include <qdatetime.h>
-#include <qapp.h>
+#include <qapplication.h>
 #include <qpushbutton.h>
 #include <unistd.h>
 #include "../krusader.h"
@@ -59,12 +59,20 @@ KRPleaseWait::KRPleaseWait( QString msg, int count, bool cancel ):
 	QPushButton* btn = new QPushButton(i18n("&Cancel"),this);
   setCancelButton(btn);
 
-	btn->setEnabled(cancel);
+	btn->setEnabled(canClose = cancel);
   setLabelText(msg);
 
 	show();
 }
 
+void KRPleaseWait::closeEvent ( QCloseEvent * e )
+{
+  if( canClose )
+    e->accept();
+  else              /* if cancel is not allowed, we disable */
+    e->ignore();         /* the window closing [x] also */
+}
+
 void KRPleaseWait::incProgress(int howMuch){
 	setProgress(progress()+howMuch);
 }
