@@ -29,8 +29,10 @@
  ***************************************************************************/
 
 #include <qstrlist.h>
+#include <kurl.h>
 #include "krmaskchoice.h"
 #include "newftpgui.h"
+#include "../VFS/krquery.h"
 
 #ifndef KRSPWIDGETS_H
 #define KRSPWIDGETS_H
@@ -45,8 +47,8 @@ class KRSpWidgets {
 public: 
 	KRSpWidgets();
 
-  static QString getMask(QString caption); // get file-mask for (un)selecting files
-  static QString newFTP();
+  static KRQuery getMask( QString caption, bool nameOnly=false ); // get file-mask for (un)selecting files
+  static KURL newFTP();
 
 private:
   static QStrList maskList;  // used by KRMaskChoiceSub 
