@@ -77,7 +77,7 @@ KCMDLine::KCMDLine( QWidget *parent, const char *name ) : QWidget( parent, name
   cmdLine->setFont( KGlobalSettings::generalFont() );
   cmdLine->setMaximumHeight( height );
   cmdLine->setCompletionObject( &completion );
-  cmdLine->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred));
+  cmdLine->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
   // load the history
   KConfigGroupSaver grpSvr( krConfig, "Private" );
   QStringList list = krConfig->readListEntry( "cmdline history" );
@@ -88,20 +88,17 @@ KCMDLine::KCMDLine( QWidget *parent, const char *name ) : QWidget( parent, name
   connect( cmdLine, SIGNAL( returnToPanel() ), this, SLOT( slotReturnFocus() ));
 
   QWhatsThis::add
-    ( cmdLine, i18n( "<qt>Well, it's quite simple actually: You write "
-                     "your command in here, and Krusader obeys.<p>"
-                     "<Tip:>Move in command-line history with &lt;Up&gt; "
-                     "and &lt;Down&gt; arrows.</qt>" ) );
+    ( cmdLine, i18n( "<qt>Well, it's actually quite simple: You type your command here and Krusader obeys.<p><Tip:>Move within command line history with &lt;Up&gt; and &lt;Down&gt; arrows.</qt>" ) );
   layout->addWidget( cmdLine, 0, 1 );
 
   // a run in terminal button
   terminal = new QToolButton( this );
-  terminal->setFixedSize( cmdLine->maximumHeight(), cmdLine->maximumHeight() );
+  terminal->setFixedSize( 22, 20 );
   terminal->setTextLabel( i18n( "If pressed, Krusader executes command line in a terminal." ) );
   terminal->setToggleButton( true );
   terminal->setOn( false );
-  QImage im = krLoader->loadIcon( "konsole", KIcon::Panel ).convertToImage();
-  terminal->setPixmap( im.scale( terminal->height(), terminal->height() ) );
+  terminal->setIconSet( SmallIcon( "konsole" ) );
+  terminal->adjustSize();  
   QWhatsThis::add
     ( terminal, i18n( "The 'run in terminal' button allows Krusader "
                       "to run console (or otherwise non-graphical) "
@@ -137,7 +134,7 @@ void KCMDLine::setCurrent( const QString &p ) {
 KCMDLine::~KCMDLine() {
    KConfigGroupSaver grpSvr( krConfig, "Private" );
    QStringList list = cmdLine->historyItems();
-   //kdWarning() << list[0] << endl;
+   //krOut << list[0] << endl;
    krConfig->writeEntry( "cmdline history", list );
    krConfig->sync();
 }
