@@ -31,8 +31,11 @@
 #include "kgcolors.h"
 #include "../defaults.h"
 #include "../Panel/krcolorcache.h"
+#include <kmessagebox.h>
 #include <klocale.h>
+#include <kfiledialog.h>
 #include <kglobalsettings.h>
+#include <kstandarddirs.h>
 #include <qhbox.h>
 #include <qheader.h>
 #include <qtabwidget.h>
@@ -54,9 +57,9 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
 
   KONFIGURATOR_CHECKBOX_PARAM generalSettings[] =
   //  cfg_class  cfg_name                     default               text                                      restart tooltip
-    {{"Colors","KDE Default",                 _KDEDefaultColors,    i18n( "Use the default KDE colors" ),     false,  "" },
-     {"Colors","Enable Alternate Background", _AlternateBackground, i18n( "Use alternate background color" ),  false,  "" },
-     {"Colors","Show Current Item Always", _ShowCurrentItemAlways, i18n( "Show current item even if not focused" ),  false,  "" }};
+    {{"Colors","KDE Default",                 _KDEDefaultColors,    i18n( "Use the default KDE colors" ),     false,  i18n( "Krusader default color configuration." ) },
+     {"Colors","Enable Alternate Background", _AlternateBackground, i18n( "Use alternate background color" ),  false, i18n(  "The Background color and the Alternate Background color alternates line by line.\nWhen you don't use the KDE default colors, you can configure the alternate colors in the Colors box." ) },
+     {"Colors","Show Current Item Always", _ShowCurrentItemAlways, i18n( "Show current item even if not focused" ),  false, i18n(  "Shows the last cursor position in the non active list panel.\nThis option is only available when you don't use the KDE default colors." ) }};
 
   generals = createCheckBoxGroup( 0, 2, generalSettings, sizeof(generalSettings)/sizeof(generalSettings[0]), generalGrp );
   generalGrid->addWidget( generals, 1, 0 );
@@ -67,7 +70,7 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
   connect( generals->find( "Enable Alternate Background" ), SIGNAL( stateChanged( int ) ), this, SLOT( generatePreview() ) );
   connect( generals->find( "Show Current Item Always" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
 
-  kgColorsLayout->addWidget( generalGrp, 0 ,0 );
+  kgColorsLayout->addMultiCellWidget( generalGrp, 0 ,0, 0, 2 );
   QHBox *hbox = new QHBox( parent );
 
   //  -------------------------- COLORS GROUPBOX ----------------------------------
@@ -172,7 +175,15 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
 
   previewGrid->addWidget( preview, 0 ,0 );
 
-  kgColorsLayout->addWidget( hbox, 1 ,0 );
+  kgColorsLayout->addMultiCellWidget( hbox, 1 ,1, 0, 2 );
+  
+  importBtn = new KPushButton(i18n("Import color-scheme"),parent);
+  kgColorsLayout->addWidget(importBtn,2,0);
+  exportBtn = new KPushButton(i18n("Export color-scheme"),parent);
+  kgColorsLayout->addWidget(exportBtn,2,1);
+  kgColorsLayout->addWidget(createSpacer(parent, ""), 2,2);
+  connect(importBtn, SIGNAL(clicked()), this, SLOT(slotImportColors()));
+  connect(exportBtn, SIGNAL(clicked()), this, SLOT(slotExportColors()));
 
   slotDisable();
 }
@@ -228,6 +239,9 @@ void KgColors::slotDisable()
 {
   bool enabled = generals->find( "KDE Default" )->isChecked();
 
+  importBtn->setEnabled(!enabled);
+  exportBtn->setEnabled(!enabled);
+  
   for( int i = 0; labelList.at( i ); i++ )
     labelList.at( i )->setEnabled( !enabled );
 
@@ -412,5 +426,113 @@ bool KgColors::apply()
   return result;
 }
 
-#include "kgcolors.moc"
+void KgColors::slotImportColors() {
+	// find $KDEDIR/share/apps/krusader
+	QString basedir = KGlobal::dirs()->findResourceDir("appdata", "total_commander.keymap");
+	// let the user select a file to load
+	QString file = KFileDialog::getOpenFileName(basedir, "*.color", 0, i18n("Select a color-scheme file"));
+	if (file == QString::null) return;
+	QFile f(file);
+	if (!f.open(IO_ReadOnly)) {
+		KMessageBox::error(this, i18n("Error: unable to read from file"), i18n("Error"));
+		return;
+	}
+	QDataStream stream(&f);
+	// ok, import away
+	deserialize(stream);
+	generatePreview();
+}
 
+void KgColors::slotExportColors() {
+	QString file = KFileDialog::getSaveFileName(QString::null, "*", 0, i18n("Select a color scheme file"));
+	if (file == QString::null) return;
+	QFile f(file);
+	if (f.exists() && KMessageBox::warningContinueCancel(this, 
+		i18n("File ")+file+i18n(" already exists. Are you sure you want to overwrite it?"),
+		i18n("Warning"), i18n("Overwrite")) != KMessageBox::Continue) return;
+	if (!f.open(IO_WriteOnly)) {
+		KMessageBox::error(this, i18n("Error: unable to write to file"), i18n("Error"));
+		return;
+	}
+	QDataStream stream(&f);
+	serialize(stream);
+}
+
+void KgColors::serialize(QDataStream & stream)
+{
+   serializeItem(stream, "Alternate Background");
+   serializeItem(stream, "Alternate Marked Background");
+   serializeItem(stream, "Background");
+   serializeItem(stream, "Current Background");
+   serializeItem(stream, "Current Foreground");
+   serializeItem(stream, "Enable Alternate Background");
+   serializeItem(stream, "Foreground");
+   serializeItem(stream, "Directory Foreground");
+   serializeItem(stream, "Executable Foreground");
+   serializeItem(stream, "Symlink Foreground");
+   serializeItem(stream, "Invalid Symlink Foreground");
+   serializeItem(stream, "Inactive Alternate Background");
+   serializeItem(stream, "Inactive Alternate Marked Background");
+   serializeItem(stream, "Inactive Background");
+   serializeItem(stream, "Inactive Current Foreground");
+   serializeItem(stream, "Inactive Current Background");
+   serializeItem(stream, "Inactive Marked Background");
+   serializeItem(stream, "Inactive Marked Current Foreground");
+   serializeItem(stream, "Inactive Marked Foreground");
+   serializeItem(stream, "Inactive Foreground");
+   serializeItem(stream, "Inactive Directory Foreground");
+   serializeItem(stream, "Inactive Executable Foreground");
+   serializeItem(stream, "Inactive Symlink Foreground");
+   serializeItem(stream, "Inactive Invalid Symlink Foreground");
+   serializeItem(stream, "KDE Default");
+   serializeItem(stream, "Marked Background");
+   serializeItem(stream, "Marked Current Foreground");
+   serializeItem(stream, "Marked Foreground");
+   serializeItem(stream, "Show Current Item Always");
+   stream << QString("") << QString("");
+}
+
+void KgColors::deserialize(QDataStream & stream)
+{
+   for (;;)
+   {
+      QString name, value;
+      stream >> name >> value;
+      if (name == "")
+         break;
+         
+      fprintf( stderr, "%s\n", name.ascii() );
+         
+      if (name == "KDE Default" || name == "Enable Alternate Background" || name == "Show Current Item Always" )
+      {
+        bool bValue = false;
+        value = value.lower();
+        if( value == "true" || value == "yes" || value == "on" || value == "1" )
+          bValue = true;
+        
+        generals->find( name )->setChecked( bValue );
+        continue;
+      }   
+      KonfiguratorColorChooser *selector = getColorSelector( name );
+      if( selector == 0 )
+        break;
+      selector->setValue( value );   
+   }
+}
+
+void KgColors::serializeItem(class QDataStream & stream, const char * name)
+{
+   stream << QString(name);
+   if( name == "KDE Default" || name == "Enable Alternate Background" || name == "Show Current Item Always" )
+   {
+     bool bValue = generals->find( name )->isChecked();
+     stream << QString( bValue ? "true" : "false" );
+   }
+   else
+   {
+     KonfiguratorColorChooser *selector = getColorSelector( name );
+     stream << selector->getValue();
+   }
+}
+
+#include "kgcolors.moc"
