@@ -31,10 +31,16 @@
 #include "kglookfeel.h"
 #include "../krusader.h"
 #include "../defaults.h"
+#include "../Dialogs/krdialogs.h"
 #include <qtabwidget.h>
 #include <klocale.h>
 #include <qtooltip.h>
 #include <qvalidator.h>
+#include <kmessagebox.h>
+#include <kfiledialog.h>
+#include <kglobal.h>
+#include <kstandarddirs.h>
+#include "../Panel/krselectionmode.h"
 
 KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
       KonfiguratorPage( first, parent, name )
@@ -57,47 +63,49 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
 
   KONFIGURATOR_CHECKBOX_PARAM settings[] =
   //   cfg_class  cfg_name                default             text                              restart tooltip
-    {{"Look&Feel","Warn On Exit",         _WarnOnExit,        i18n( "Warn on exit" ),           false,  ""},
-     {"Look&Feel","Minimize To Tray",     _MinimizeToTray,    i18n( "Minimize to tray" ),       false,  ""},
-     {"Look&Feel","Show Hidden",          _ShowHidden,        i18n( "Show hidden files" ),      false,  ""},
-     {"Look&Feel","Mark Dirs",            _MarkDirs,          i18n( "Automark directories" ),   false,  ""},
-     {"Look&Feel","Case Sensative Sort",  _CaseSensativeSort, i18n( "Case sensitive sorting" ), true ,  ""},
-     {"Look&Feel","Fullpath Tab Names",   _FullPathTabNames,  i18n( "Use fullpath tab names" ), true ,  ""},
-     //{"Look&Feel","Single Click Selects", false,              i18n( "Single click executes" ),   false,  ""},
-     {"Look&Feel","New Style Quicksearch",  _NewStyleQuicksearch, i18n( "New style quicksearch" ), false,  ""},
-     {"Look&Feel","Case Sensitive Quicksearch",  _CaseSensitiveQuicksearch, i18n( "Case sensitive quicksearch" ), false,  ""},
+    {{"Look&Feel","Warn On Exit",         _WarnOnExit,        i18n( "Warn on exit" ),           false,  i18n( "Display a warning when you try to exit Krusader." ) },
+     {"Look&Feel","Minimize To Tray",     _MinimizeToTray,    i18n( "Minimize to tray" ),       false,  i18n( "When minimizing Krusader, its icon will appear in the system tray instead of the taskbar." ) },
+     {"Look&Feel","Show Hidden",          _ShowHidden,        i18n( "Show hidden files" ),      false,  i18n( "Display the dot files" ) },
+     {"Look&Feel","Mark Dirs",            _MarkDirs,          i18n( "Automark directories" ),   false,  i18n( "When matching the select criteria, directories will also be marked" ) },
+     {"Look&Feel","Case Sensative Sort",  _CaseSensativeSort, i18n( "Case sensitive sorting" ), true ,  i18n( "All files beginning with capital letters appear before files beginning with non-capital letters (UNIX default)." ) },
+     {"Look&Feel","Fullpath Tab Names",   _FullPathTabNames,  i18n( "Use full path tab names" ), true ,  i18n( "Display the full path in the Folder Tabs; otherwise, only the last part of the path will be displayed." ) },
+     //{"Look&Feel","Single Click Selects", false,              i18n( "Single click executes" ),   false,  i18n( "" ) },
+     {"Look&Feel","New Style Quicksearch",  _NewStyleQuicksearch, i18n( "New style quicksearch" ), false,  i18n( "Opens a quick search dialog box." ) },
+     {"Look&Feel","Case Sensitive Quicksearch",  _CaseSensitiveQuicksearch, i18n( "Case sensitive quicksearch" ), false,  i18n( "All files beginning with capital letters appear before files beginning with non-capital letters (UNIX default)." ) },
     };
 
   cbs = createCheckBoxGroup( 2, 0, settings, 8/*9*/, lookFeelGrp );
   lookFeelGrid->addWidget( cbs, 0, 0 );
   connect( cbs->find( "New Style Quicksearch" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
 
-  		lookFeelGrid->addWidget( createLine( lookFeelGrp, "lookSep1" ), 1, 0 );
+  lookFeelGrid->addWidget( createLine( lookFeelGrp, "lookSep1" ), 1, 0 );
   
-	addLabel( lookFeelGrid, 7, 0, i18n( "Single click / Double click Selection:" ),
+  addLabel( lookFeelGrid, 7, 0, i18n( "Single click / Double click Selection:" ),
             lookFeelGrp, "lookAndFeelLabel0" );
-				
-   KONFIGURATOR_NAME_VALUE_PAIR singleOrDoubleClick[] =
-    {{ i18n( "Double-click selects (classic)" ),                   "0" },
-     { i18n( "Obey KDE's global selection policy" ),               "1" }};    
+
+   KONFIGURATOR_NAME_VALUE_TIP singleOrDoubleClick[] =
+  //          name                                               value  tooltip
+    {{ i18n( "Double-click selects (classic)" ),                   "0", i18n( "A single click on a file will select and focus, a double click opens the file or steps into the directory." ) },
+     { i18n( "Obey KDE's global selection policy" ),               "1", i18n( "Use the KDE Kcontrol setting: KDE Control Center->Peripherals->Mouse" ) }};    
   KonfiguratorRadioButtons *clickRadio = createRadioButtonGroup( "Look&Feel", "Single Click Selects", "0", 1, 0, singleOrDoubleClick, 2, lookFeelGrp, "myLook&FeelRadio0", true );
   lookFeelGrid->addWidget( clickRadio, 8, 0 );
   
   
- 		 lookFeelGrid->addWidget( createLine( lookFeelGrp, "lookSep2" ), 9, 0 );
+  lookFeelGrid->addWidget( createLine( lookFeelGrp, "lookSep2" ), 9, 0 );
   
   addLabel( lookFeelGrid, 10, 0, i18n( "Mouse Selection Mode:" ),
             lookFeelGrp, "lookAndFeelLabel4" );
-  KONFIGURATOR_NAME_VALUE_PAIR mouseSelection[] =
-    {{ i18n( "Classic (both keys combined)" ),                   "0" },
-     { i18n( "Left mouse button selects" ),                      "1" },    
-     { i18n( "Right button selects (Windows Commander style)" ), "2" }};
-  KonfiguratorRadioButtons *mouseRadio = createRadioButtonGroup( "Look&Feel", "Mouse Selection",
-      "0", 1, 0, mouseSelection, 3, lookFeelGrp, "myLook&FeelRadio", false );
+  KONFIGURATOR_NAME_VALUE_TIP mouseSelection[] =
+  //            name                 value  tooltip
+    {{ i18n( "Krusader Mode" ),        "0", i18n( "Both keys allow selecting files. To select more than one file, hold the Ctrl key and click the left mouse button.\nRight-click menu is invoked using a short click on the right mouse button." ) },
+     { i18n( "Konqueror Mode" ),       "1", i18n( "Pressing the left mouse button selects files - you can click and select multiple files.\nRight-click menu is invoked using a short click on the right mouse button." ) },    
+     { i18n( "Total-Commander Mode" ), "2", i18n( "The left mouse button does not select, but sets the current file without affecting the current selection.\nThe right mouse button selects multiple files and the right-click menu is invoked by pressing\nand holding the right mouse button." ) },
+	  { i18n( "Custom Selection Mode" ),       "3", i18n( "Design your own selection mode!" ) }};
+ mouseRadio = createRadioButtonGroup( "Look&Feel", "Mouse Selection",
+      "0", 1, 0, mouseSelection, 4, lookFeelGrp, "myLook&FeelRadio", true );
   lookFeelGrid->addWidget( mouseRadio, 11, 0 );
-  for( int i=0; i!=3; i++ )
-    mouseRadio->find(i)->setEnabled( false ); /* disable all buttons */
-  
+  connect(mouseRadio, SIGNAL(clicked(int)), this, SLOT(slotSelectionModeChanged(int)));
+	
   lookAndFeelLayout->addWidget( lookFeelGrp, 0, 0 );
   
   //  ---------------------------- PANEL TAB -------------------------------------
@@ -131,19 +139,19 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
 
   panelGrid->addWidget( createLine( panelGrp, "lookSep2" ), 2, 0 );
 
-  addLabel( panelGrid, 3, 0, i18n( "Visible Columns:" ),
+  addLabel( panelGrid, 3, 0, i18n( "Show Columns:" ),
             panelGrp, "panelLabel" );
 
   KONFIGURATOR_CHECKBOX_PARAM fields[] =
   //   cfg_class  cfg_name                default text                                  restart tooltip
-    {{"Look&Feel","Ext Column",           true,   i18n( "Extension" ),           true ,  ""},
-     {"Look&Feel","Mime Column",          false,  i18n( "Mimetype" ),            true ,  ""},
-     {"Look&Feel","Size Column",          true,   i18n( "Size" ),                true ,  ""},
-     {"Look&Feel","DateTime Column",      true,   i18n( "Date and Time" ),       true ,  ""},
-     {"Look&Feel","Perm Column",          false,  i18n( "Permission" ),          true ,  ""},
-     {"Look&Feel","KrPerm Column",        true,   i18n( "Krusader Permission" ), true ,  ""},
-     {"Look&Feel","Owner Column",         false,  i18n( "Owner" ),               true ,  ""},
-     {"Look&Feel","Group Column",         false,  i18n( "Group" ),               true ,  ""},
+    {{"Look&Feel","Ext Column",           true,   i18n( "Extension" ),           true ,  i18n( "Show the last part of the filename (part after the last dot) in the Extension Column and\nnot as a complete filename in the Name Column like e.g. Konqueror does." ) },
+     {"Look&Feel","Mime Column",          false,  i18n( "Mimetype" ),            true ,  i18n( "Show the Mimetype Column" ) },
+     {"Look&Feel","Size Column",          true,   i18n( "Size" ),                true ,  i18n( "Show the Size Column" ) },
+     {"Look&Feel","DateTime Column",      true,   i18n( "Date and Time" ),       true ,  i18n( "Show the Date and Time Column" ) },
+     {"Look&Feel","Perm Column",          false,  i18n( "Permission" ),          true ,  i18n( "Show the Full Permissions Column, e.g. '-rw-r--r--'" ) },
+     {"Look&Feel","KrPerm Column",        true,   i18n( "Krusader Permission" ), true ,  i18n( "Show only the rights of the current user, e.g. '-rw'" ) },
+     {"Look&Feel","Owner Column",         false,  i18n( "Owner" ),               true ,  i18n( "Show the Owner Column" ) },
+     {"Look&Feel","Group Column",         false,  i18n( "Group" ),               true ,  i18n( "Show the Group Column" ) },
     };
 
   KonfiguratorCheckBoxGroup *flds = createCheckBoxGroup( 0, 4, fields, 8, panelGrp );
@@ -154,8 +162,8 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   KONFIGURATOR_CHECKBOX_PARAM panelSettings[] =
   //   cfg_class  cfg_name                default text                                  restart tooltip
     {
-	 {"Look&Feel","With Icons",           _WithIcons,   i18n( "Use icons in the filenames" ), true ,  ""},
-	 {"Look&Feel","Human Readable Size",  _HumanReadableSize, i18n( "Use human-readable file size" ), true ,  ""},
+	 {"Look&Feel","With Icons",           _WithIcons,   i18n( "Use icons in the filenames" ), true ,  i18n( "Show the icons for filenames and folders." ) },
+	 {"Look&Feel","Human Readable Size",  _HumanReadableSize, i18n( "Use human-readable file size" ), true ,  i18n( "File sizes are displayed in B, KB, MB and GB, not just in bytes." ) },
     };
 
   KonfiguratorCheckBoxGroup *panelSett = createCheckBoxGroup( 0, 2, panelSettings, 2, panelGrp );
@@ -178,10 +186,21 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   tabWidget->insertTab( tab_3, i18n( "Key-bindings" ) );
 
   keyBindingsLayout = new QGridLayout( tab_3 );
-  KonfiguratorKeyChooser *keyBindings = new KonfiguratorKeyChooser(krApp->actionCollection(),tab_3);
+  keyBindings = new KonfiguratorKeyChooser(krApp->actionCollection(),tab_3);
   connect( keyBindings, SIGNAL( reload( KonfiguratorKeyChooser * ) ), this, SLOT( slotReload( KonfiguratorKeyChooser *) ) );
-  keyBindingsLayout->addWidget(keyBindings->keyChooserWidget(),0,0);
+  keyBindingsLayout->addMultiCellWidget(keyBindings->keyChooserWidget(),0,0,0,2);
   registerObject( keyBindings );
+  
+  // import and export shortcuts
+  KPushButton *importBtn = new KPushButton(i18n("Import shortcuts"),tab_3);
+  keyBindingsLayout->addWidget(importBtn,1,0);
+  QToolTip::add(  importBtn, i18n( "Load a Key-binding profile, e.g., total_commander.keymap" ) );
+  KPushButton *exportBtn = new KPushButton(i18n("Export shortcuts"),tab_3);
+  keyBindingsLayout->addWidget(exportBtn,1,1);
+  QToolTip::add(  exportBtn, i18n( "Save current Key-bindings in a keymap file." ) );
+  keyBindingsLayout->addWidget(createSpacer(tab_3, "tab3spacer"), 1,2);
+  connect(importBtn, SIGNAL(clicked()), this, SLOT(slotImportShortcuts()));
+  connect(exportBtn, SIGNAL(clicked()), this, SLOT(slotExportShortcuts()));
 
   //  -------------------------- Panel Toolbar TAB ----------------------------------
   QWidget     *tab_4 = new QWidget( tabWidget, "tab_4" );
@@ -193,7 +212,7 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
 
   KONFIGURATOR_CHECKBOX_PARAM panelToolbarActiveCheckbox[] = 
   //   cfg_class    cfg_name                default        text                             restart tooltip
-    {{"Look&Feel", "Panel Toolbar visible", _PanelToolBar, i18n( "Panel Toolbar visible" ), false,  ""}
+    {{"Look&Feel", "Panel Toolbar visible", _PanelToolBar, i18n( "Show Panel Toolbar" ), false,  i18n( "Krusader will display the Panel Toolbar." ) }
   };
 
   panelToolbarActive = createCheckBoxGroup( 1, 0, panelToolbarActiveCheckbox, 1, tab_4, "panelToolbarActive");
@@ -205,12 +224,12 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   KONFIGURATOR_CHECKBOX_PARAM panelToolbarCheckboxes[] = 
     {
   //   cfg_class    cfg_name                default             text                       restart tooltip
-     {"Look&Feel",  "Open Button Visible",  _Open,      i18n( "Open button" ),     true ,  ""},
-     {"Look&Feel",  "Equal Button Visible", _cdOther,   i18n( "Equal button (=)" ),true ,  ""},
-     {"Look&Feel",  "Up Button Visible",    _cdUp,      i18n( "Up button (..)" ),  true ,  ""},
-     {"Look&Feel",  "Home Button Visible",  _cdHome,    i18n( "Home button (~)" ), true ,  ""},
-     {"Look&Feel",  "Root Button Visible",  _cdRoot,    i18n( "Root button (/)" ), true ,  ""},
-     {"Look&Feel",  "SyncBrowse Button Visible",  _syncBrowseButton,    i18n( "Toggle-button for sync-browsing" ), true ,  ""},
+     {"Look&Feel",  "Open Button Visible",  _Open,      i18n( "Open button" ),     true ,  i18n( "Opens the directory browser." ) },
+     {"Look&Feel",  "Equal Button Visible", _cdOther,   i18n( "Equal button (=)" ),true ,  i18n( "Changes the panel directory to the other panel directory." ) },
+     {"Look&Feel",  "Up Button Visible",    _cdUp,      i18n( "Up button (..)" ),  true ,  i18n( "Changes the panel directory to the parent directory." ) },
+     {"Look&Feel",  "Home Button Visible",  _cdHome,    i18n( "Home button (~)" ), true ,  i18n( "Changes the panel directory to the home directory." ) },
+     {"Look&Feel",  "Root Button Visible",  _cdRoot,    i18n( "Root button (/)" ), true ,  i18n( "Changes the panel directory to the root directory." ) },
+     {"Look&Feel",  "SyncBrowse Button Visible",  _syncBrowseButton,    i18n( "Toggle-button for sync-browsing" ), true ,  i18n( "Each directory-change in the panel is also performed in the other panel." ) },
     };
   
   
@@ -234,9 +253,9 @@ void KgLookFeel::slotReload( KonfiguratorKeyChooser * oldChooser )
   removeObject( oldChooser );
   delete oldChooser;
 
-  KonfiguratorKeyChooser *keyBindings = new KonfiguratorKeyChooser(krApp->actionCollection(),tab_3);
+  keyBindings = new KonfiguratorKeyChooser(krApp->actionCollection(),tab_3);
   connect( keyBindings, SIGNAL( reload( KonfiguratorKeyChooser * ) ), this, SLOT( slotReload( KonfiguratorKeyChooser *) ) );
-  keyBindingsLayout->addWidget(keyBindings->keyChooserWidget(),0,0);
+  keyBindingsLayout->addMultiCellWidget(keyBindings->keyChooserWidget(),0,0,0,2);
   registerObject( keyBindings );
   keyBindings->keyChooserWidget()->show();
 }
@@ -269,5 +288,40 @@ void KgLookFeel::slotEnablePanelToolbar()
   pnlcbs->find( "Open Button Visible"     )->setEnabled(enableTB);  
 }
 
+void KgLookFeel::slotImportShortcuts() {
+	// find $KDEDIR/share/apps/krusader
+	QString basedir = KGlobal::dirs()->findResourceDir("appdata", "total_commander.keymap");
+	// let the user select a file to load
+	QString file = KFileDialog::getOpenFileName(basedir, "*.keymap", 0, i18n("Select a shortcuts file"));
+	if (file == QString::null) return;
+	// check if there's an info file with the keymap
+	QFile info(file+".info");
+	if (info.open(IO_ReadOnly)) {
+		QTextStream stream(&info);
+		QStringList infoText = QStringList::split("\n", stream.read());
+		if (KMessageBox::questionYesNoList(krApp, i18n("The following information was attached to the keymap.\n"
+				"Are you sure you want to import this keymap ?"), infoText)!=KMessageBox::Yes)
+			return;
+	}
+	// ok, import away
+	krApp->importKeyboardShortcuts(file);
+	slotReload(keyBindings);	
+	keyBindings->setChanged();
+}
+
+void KgLookFeel::slotExportShortcuts() {
+	QString file = KFileDialog::getSaveFileName(QString::null, "*", 0, i18n("Select a shortcuts file"));
+	if (file == QString::null) return;
+	krApp->exportKeyboardShortcuts(file);
+}
+
+void KgLookFeel::slotSelectionModeChanged(int mode) {
+	// mode 3 == user defined mode (ugly, but no #defines yet)
+	if (mode == 3) {
+		if (UserSelectionModeDlg::createCustomMode(this) == QDialog::Accepted)
+			mouseRadio->extension()->setChanged();
+	}
+}
+
 #include "kglookfeel.moc"
 
