@@ -49,6 +49,7 @@ protected:
   KonfiguratorCheckBoxGroup *cbs;
   KonfiguratorCheckBoxGroup *pnlcbs;
   KonfiguratorCheckBoxGroup *panelToolbarActive;
+  KonfiguratorRadioButtons *mouseRadio;
   
   QWidget     *tab_panel;
   
@@ -62,6 +63,12 @@ protected slots:
   void slotReload( KonfiguratorKeyChooser * oldChooser );
   void slotDisable();
   void slotEnablePanelToolbar();
+  void slotImportShortcuts();
+  void slotExportShortcuts();
+  void slotSelectionModeChanged(int mode);
+  
+private:
+  KonfiguratorKeyChooser *keyBindings;
 };
 
 class KonfiguratorEditToolbarWidget : public KonfiguratorExtension
