@@ -45,6 +45,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "kmountmangui.h"
 #include <unistd.h>
 #include "../Dialogs/krprogress.h"
+#include "../VFS/krpermhandler.h"
 
 #ifdef _OS_SOLARIS_
 #define FSTAB "/etc/vfstab"
@@ -73,7 +74,7 @@ KMountMan::KMountMan() : QObject(), Operational( false ), waiting(false), mountM
 #endif
 
 	// list of FS that we don't allow to mount/unmount
-	nonmount_fs << "supermount" << "auto";
+	nonmount_fs << "supermount";
 	{
 		KConfigGroupSaver saver(krConfig, "Advanced");
 		QStringList nonmount = QStringList::split(",", krConfig->readEntry("Nonmount Points", _NonMountPoints));
@@ -94,7 +95,7 @@ bool KMountMan::invalidFilesystem(QString type) {
 
 // this is an ugly hack, but type can actually be a mountpoint. oh well...
 bool KMountMan::nonmountFilesystem(QString type, QString mntPoint) {
-	return ((nonmount_fs.contains(type) > 0) || (nonmount_fs_mntpoint.contains(mntPoint) > 0));
+	return((nonmount_fs.contains(type) > 0) || (nonmount_fs_mntpoint.contains(mntPoint) > 0));
 }
 
 void KMountMan::mainWindow() {
@@ -193,7 +194,7 @@ void KMountMan::eject( QString mntPoint ) {
    proc << KrServices::fullPathName( "eject" ) << "\"" + mntPoint + "\"";
    proc.start( KProcess::Block );
    if ( !proc.normalExit() || proc.exitStatus() != 0 )         // if we failed with eject
-      KMessageBox::information( 0, i18n( "Error ejecting device ! You need to have 'eject' in your path." ), i18n( "Error" ), "CantExecuteEjectWarning" );
+      KMessageBox::information( 0, i18n( "Error ejecting device! You need to have 'eject' in your path." ), i18n( "Error" ), "CantExecuteEjectWarning" );
 }
 
 // returns true if the path is an ejectable mount point (at the moment CDROM)
