@@ -53,7 +53,7 @@ public:
 	KrDetailedViewProperties() {
 		for ( int i = 0; i < MAX_COLUMNS; i++ ) column[i] = Unused;
 		filter = KrViewProperties::All;
-		filterMask = "*";
+		filterMask = KRQuery( "*" );
 	}
 };
 
@@ -113,6 +113,8 @@ signals:
 
 protected:
    void newColumn( KrDetailedViewProperties::ColumnType type );
+   void selectColumns();
+   
    virtual void keyPressEvent( QKeyEvent *e );
    virtual void contentsMousePressEvent( QMouseEvent *e );
    virtual void contentsMouseReleaseEvent (QMouseEvent *e);
@@ -121,8 +123,10 @@ protected:
    virtual bool acceptDrag( QDropEvent* e ) const;
    virtual void contentsDropEvent( QDropEvent *e );
    virtual void contentsDragMoveEvent( QDragMoveEvent *e );
+   virtual QRect drawItemHighlighter(QPainter *painter, QListViewItem *item);
    virtual void startDrag();
    virtual bool event( QEvent *e );
+   virtual bool eventFilter( QObject * watched, QEvent * e );
 	virtual void initProperties();
 
 protected slots:
@@ -139,6 +143,7 @@ protected slots:
    void stopQuickSearch( QKeyEvent* );
    void handleQuickSearchEvent( QKeyEvent* );
    void setNameToMakeCurrent( QListViewItem *it );
+	void sortOrderChanged(int);
 
    /**
     * used internally to produce the signal middleButtonClicked()
@@ -154,7 +159,9 @@ public slots:
 
 private:
    static QString ColumnName[ KrDetailedViewProperties::MAX_COLUMNS ];
-   bool _focused;
+   bool _focused, swushSelects;
+   QPoint dragStartPos;
+   QListViewItem *lastSwushPosition;
    bool caseSensitiveSort;
    KrViewItem *_currDragItem;
    QString _nameInKConfig;
@@ -167,6 +174,8 @@ private:
    QTimer contextMenuTimer;
    QPoint contextMenuPoint;
 	QDict<KrDetailedViewItem> dict;
+        
+   QListViewItem *currentlyRenamedItem;
 };
 
 #endif /* KRDETAILEDVIEW_H */
