@@ -37,6 +37,8 @@
 #include <klistview.h>
 #include <qguardedptr.h>
 
+//#define FASTER
+
 class QPixmap;
 class KrDetailedView;
 
@@ -72,6 +74,9 @@ private:
 	// used INTERNALLY when calculation of dir size changes the displayed size of the item
 	inline void setSize(KIO::filesize_t size) { _vf->vfile_setSize(size); }
 	static const QColor & setColorIfContrastIsSufficient(const QColor & background, const QColor & color1, const QColor & color2);
+#ifdef FASTER	
+	bool initiated;
+#endif
 };
 
 #endif
