@@ -70,6 +70,7 @@ class DirHistoryQueue;
 class PanelPopup;
 class SyncBrowseButton;
 class KrBookmarkButton;
+class KPushButton;
 
 class ListPanel : public QWidget {
    friend class ListPanelFunc;
@@ -80,10 +81,9 @@ public:
    // constructor create the panel, but DOESN'T fill it with data, use start()
    ListPanel( QWidget *parent, bool &left, const char *name = 0 );
    ~ListPanel();
-   void start( QString path = QString::null );
-   inline QString getPath() {
-      return virtualPath;
-   }
+   void start( KURL url = KURL(), bool immediate = false );
+   KURL virtualPath() const;
+	QString realPath() const;
    QString getCurrentName();
    void getSelectedNames( QStringList* fileNames ) {
       view->getSelectedItems( fileNames );
@@ -95,7 +95,7 @@ public slots:
    void gotStats( const QString &mountPoint, unsigned long kBSize, unsigned long kBUsed, unsigned long kBAvail); // displays filesystem status
    void popRightClickMenu( const QPoint& );
    void popEmptyRightClickMenu( QListViewItem *, const QPoint &, int );
-   void select(QString mask, bool select);
+   void select( KRQuery query, bool select);
    void select( bool, bool );      // see doc in ListPanel
    void invertSelection();       // see doc in ListPanel
    void compareDirs();
@@ -103,7 +103,7 @@ public slots:
    void slotUpdate();			                  // when the vfs finish to update...
    void slotUpdateTotals();
    void slotStartUpdate();                   // internal
-   void slotGetStats( QString path );          // get the disk-free stats
+   void slotGetStats( const KURL& url );          // get the disk-free stats
    void setFilter( KrViewProperties::FilterSpec f );
    void slotFocusAndCDRoot();
    void slotFocusAndCDHome();
@@ -134,6 +134,12 @@ protected slots:
    void handleDropOnTotals( QDropEvent * );                   // handles drops on the totals line
    void handleDropOnStatus( QDropEvent * );                   // handles drops on the status line
    void startDragging( QStringList, QPixmap );
+	// those handle the in-panel refresh notifications
+	void slotJobStarted(KIO::Job* job);
+	void inlineRefreshInfoMessage( KIO::Job* job, const QString &msg );
+	void inlineRefreshListResult(KIO::Job* job);
+	void inlineRefreshPercent( KIO::Job*, unsigned long );
+	void inlineRefreshCancel();
 
 signals:
    void signalStatus( QString msg );       // emmited when we need to update the status bar
@@ -146,12 +152,10 @@ public:
    ListPanelFunc	*func;
    KrView *view;
    ListPanel	*otherPanel;
-   QString virtualPath;
-   QString realPath;
    int colorMask;
    bool compareMode;
    //FilterSpec	   filter;
-   QString	filterMask;
+   KRQuery filterMask;
    QPixmap currDragPix;
    QListViewItem *currDragItem;
    KDiskFreeSp* statsAgent;
@@ -169,7 +173,13 @@ public:
    DirHistoryQueue* dirHistoryQueue;
    DirHistoryButton* historyButton;
    SyncBrowseButton *syncBrowseButton;
+	KPushButton *inlineRefreshCancelButton;
+	KIO::Job *inlineRefreshJob;
 
+protected:
+   KURL _realPath; // named with _ to keep realPath() compatability
+   
+	
 private:
    bool &_left;
 	QValueList<int> popupSizes;
