@@ -49,6 +49,7 @@ A
 #include <kio/netaccess.h>
 #include <kstandarddirs.h>
 #include <ktempdir.h> 
+#include <kurlrequester.h>
 // Krusader Includes
 #include "panelfunc.h"
 #include "krcalcspacedialog.h"
@@ -58,6 +59,7 @@ A
 #include "../defaults.h"
 #include "../VFS/vfile.h"
 #include "../VFS/vfs.h"
+#include "../VFS/virt_vfs.h"
 #include "../VFS/krarchandler.h"
 #include "../VFS/krpermhandler.h"
 #include "../VFS/krvfshandler.h"
@@ -70,7 +72,7 @@ A
 #include "../krservices.h"
 #include "../GUI/syncbrowsebutton.h"
 #include "krdrag.h"
-
+#include <kurldrag.h>
 
 //////////////////////////////////////////////////////////
 //////          ----------      List Panel -------------                ////////
@@ -83,13 +85,18 @@ panel( parent ), inRefresh( false ), vfsP( 0 ) {
 }
 
 void ListPanelFunc::openUrl( const QString& url, const QString& nameToMakeCurrent ) {
-	openUrl( vfs::fromPathOrURL( url ), nameToMakeCurrent );
+	openUrl( vfs::fromPathOrURL( 
+		// KURLRequester is buggy: it should return a string containing "/home/shie/downloads"
+		// but it returns "~/downloads" which is parsed incorrectly by vfs::fromPathOrURL.
+		// replacedPath should replace ONLY $HOME and environment variables
+		panel->origin->completionObject()->replacedPath(url) )
+		, nameToMakeCurrent );
 }
 
-void ListPanelFunc::openUrl( const KURL& urlIn, const QString& nameToMakeCurrent ) {
+void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	KURL url = urlIn;
 	url.cleanPath();
-
+	
 	// check for special cases first - don't refresh here !
 	// you may call openUrl or vfs_refresh()
 	if ( !url.isValid() ) {
@@ -99,35 +106,19 @@ void ListPanelFunc::openUrl( const KURL& urlIn, const QString& nameToMakeCurrent
 			// possible relative URL - translate to full URL
 			url = files() ->vfs_getOrigin();
 			url.addPath( urlIn.url() );
-			kdDebug()<< urlIn.url() << "," << url.url() <<endl;
+			//kdDebug()<< urlIn.url() << "," << url.url() <<endl;
 		} else {
 			panel->slotStartUpdate();  // refresh the panel
 			return ;
 		}
 	}
 
-	// first the other dir, then the active! Else the focus changes and the other becomes active
-	if ( panel->syncBrowseButton->state() == SYNCBROWSE_CD ) {
-		// prevents that the sync-browsing circles itself to death	
-		static bool inSync = false;
-		if( !inSync ){
-			inSync = true;
-			//do sync-browse stuff....
-			OTHER_FUNC->files() ->vfs_setQuiet( true );
-			// the trailing slash is nessesary because krusader provides Dir's without it
-			OTHER_FUNC->openUrl( KURL::relativeURL( panel->getPath() + "/", url.url() ) );
-			OTHER_FUNC->files() ->vfs_setQuiet( false );
-		
-			inSync = false;
-		}
-	}
-
 	panel->slotFocusOnMe();
 
 	// if we are not refreshing to current URL
 	if ( !files() ->vfs_getOrigin().equals( url, true ) ) {
 		// change the cursor to busy
-		krApp->setCursor( KCursor::waitCursor() );
+		panel->setCursor( KCursor::waitCursor() );
 		// clear the view - to avoid a repaint crash
 		panel->view->clear();
 	}
@@ -147,9 +138,11 @@ void ListPanelFunc::openUrl( const KURL& urlIn, const QString& nameToMakeCurrent
 		if ( !v )
 			continue; //this should not happen !
 		if ( v != vfsP ) {
-			delete vfsP;
+			vfsP->deleteLater();
 			vfsP = v; // v != 0 so this is safe
 		}
+		connect( files(), SIGNAL(startJob(KIO::Job* )),
+				panel, SLOT(slotJobStarted(KIO::Job* )));
 		if ( vfsP->vfs_refresh( u ) )
 			break; // we have a valid refreshed URL now
 		// prevent repeated error messages
@@ -172,26 +165,54 @@ void ListPanelFunc::openUrl( const KURL& urlIn, const QString& nameToMakeCurrent
 	         panel, SLOT( slotItemUpdated( vfile* ) ) );
 	connect( files(), SIGNAL( deletedVfile( const QString& ) ),
 	         panel, SLOT( slotItemDeleted( const QString& ) ) );
-
+	
 	// on local file system change the working directory
 	if ( files() ->vfs_getType() == vfs::NORMAL )
 		chdir( files() ->vfs_getOrigin().path().local8Bit() );
 }
 
-void ListPanelFunc::delayedOpenUrl( const KURL& url ) {
+void ListPanelFunc::openUrl( const KURL& url, const QString& nameToMakeCurrent ) {
+	panel->inlineRefreshCancel();
+	// first the other dir, then the active! Else the focus changes and the other becomes active
+	if ( panel->syncBrowseButton->state() == SYNCBROWSE_CD ) {
+		// prevents that the sync-browsing circles itself to death
+		static bool inSync = false;
+		if( ! inSync ){
+			inSync = true;
+			//do sync-browse stuff....
+			KURL otherDir = OTHER_PANEL->virtualPath();
+			OTHER_FUNC->files() ->vfs_setQuiet( true );
+			// the trailing slash is nessesary because krusader provides Dir's without it
+			// we can't use openUrl because the delay don't allow a check if the panel has realy changed!
+			OTHER_FUNC->immediateOpenUrl( KURL::relativeURL( panel->virtualPath().url() + "/", url.url() ) );
+			OTHER_FUNC->files() ->vfs_setQuiet( false );
+			// now we need to test ACTIVE_PANEL because the openURL has changed the active panel!!
+			if ( ACTIVE_PANEL->virtualPath().equals( otherDir ) ) {
+				// deactivating the sync-browse if syncbrowse not possible
+				panel->syncBrowseButton->setOn( false );
+			}
+			inSync = false;
+		}
+	}
+	this->nameToMakeCurrent = nameToMakeCurrent;
 	delayURL = url;               /* this function is useful for FTP url-s and bookmarks */
 	delayTimer.start( 0, true );  /* to avoid qApp->processEvents() deadlock situaltion */
 }
 
+void ListPanelFunc::refresh() {
+	openUrl(panel->virtualPath()); // re-read the files
+}
+
 void ListPanelFunc::doOpenUrl() {
-	openUrl( delayURL );
+	immediateOpenUrl( delayURL );
 }
 
 void ListPanelFunc::goBack() {
 	if ( urlStack.isEmpty() )
 		return ;
 
-	urlStack.pop();
+	if ( urlStack.top().equals( files() ->vfs_getOrigin() ) )
+		urlStack.pop();
 	openUrl( urlStack.top(), files() ->vfs_getOrigin().fileName() );
 
 	if ( urlStack.isEmpty() )
@@ -211,7 +232,7 @@ void ListPanelFunc::redirectLink() {
 	QString file = files() ->vfs_getFile( vf->vfile_getName() ).path( -1 );
 	QString currentLink = vf->vfile_getSymDest();
 	if ( currentLink.isEmpty() ) {
-		KMessageBox::sorry( krApp, i18n( "The current file is not a link, so i can't redirect it." ) );
+		KMessageBox::sorry( krApp, i18n( "The current file is not a link, so I can't redirect it." ) );
 		return ;
 	}
 
@@ -296,7 +317,7 @@ void ListPanelFunc::view() {
 
 void ListPanelFunc::terminal() {
 	QString save = getcwd( 0, 0 );
-	chdir( panel->realPath.local8Bit() );
+	chdir( panel->realPath().local8Bit() );
 
 	KProcess proc;
 	krConfig->setGroup( "General" );
@@ -339,18 +360,13 @@ void ListPanelFunc::moveFiles() {
 	if ( fileNames.isEmpty() )
 		return ;  // safety
 
-	QString dest = panel->otherPanel->getPath();
-	/* --=={ Patch by Heiner <h.eichmann@gmx.de> }==-- */
+	KURL dest = panel->otherPanel->virtualPath();
 
-	//krConfig->setGroup( "Archives" );
-	//if ( !krConfig->readBoolEntry( "Allow Move Into Archive", _MoveIntoArchive ) )
-	//{
-	QString destProtocol = panel->otherPanel->func->files() ->vfs_getOrigin().protocol();
+	QString destProtocol = dest.protocol();
 	if ( destProtocol == "krarc" || destProtocol == "tar" || destProtocol == "zip" ) {
 		KMessageBox::sorry( krApp, i18n( "Moving into archive is disabled" ) );
 		return ;
 	}
-	//}
 
 	krConfig->setGroup( "Advanced" );
 	if ( krConfig->readBoolEntry( "Confirm Move", _ConfirmMove ) ) {
@@ -361,10 +377,8 @@ void ListPanelFunc::moveFiles() {
 			s.sprintf( i18n( "Move %d files to:" ).local8Bit(), fileNames.count() );
 
 		// ask the user for the copy dest
-		KChooseDir *chooser = new KChooseDir( 0, s, panel->otherPanel->getPath() );
-		dest = chooser->dest;
-		if ( dest == QString::null )
-			return ; // the usr canceled
+		dest = KChooseDir::getDir(s, dest, panel->virtualPath());
+		if ( dest.isEmpty() ) return ; // the user canceled
 	}
 
 	if ( fileNames.isEmpty() )
@@ -377,22 +391,16 @@ void ListPanelFunc::moveFiles() {
 	panel->prepareToDelete();
 
 	// if we are not moving to the other panel :
-	if ( panel->otherPanel->getPath() != dest ) {
-		if ( dest.left( 1 ) != "/" ) {
-			dest = files() ->vfs_workingDir() + "/" + dest;
-		}
+	if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
 		// you can rename only *one* file not a batch,
 		// so a batch dest must alwayes be a directory
-		if ( ( fileNames.count() > 1 ) && ( dest.right( 1 ) != "/" ) )
-			dest = dest + "/";
-		QDir().mkdir( dest.left( dest.findRev( "/" ) ) );
-		KURL destUrl;
-		destUrl.setPath( dest );
-		KIO::Job* job = new KIO::CopyJob( *fileUrls, destUrl, KIO::CopyJob::Move, false, true );
+		if ( fileNames.count() > 1 ) dest.adjustPath(1);
+		KIO::Job* job = new KIO::CopyJob( *fileUrls, dest, KIO::CopyJob::Move, false, true );
+		job->setAutoErrorHandlingEnabled( true );
 		// refresh our panel when done
 		connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( refresh() ) );
 		// and if needed the other panel as well
-		if ( dest.startsWith( panel->otherPanel->getPath() ) )
+		if ( dest.equals( panel->otherPanel->virtualPath(), true ) )
 			connect( job, SIGNAL( result( KIO::Job* ) ), panel->otherPanel->func, SLOT( refresh() ) );
 
 	} else { // let the other panel do the dirty job
@@ -413,7 +421,6 @@ void ListPanelFunc::rename() {
 
 // called by signal itemRenamed() from the view to complete the renaming process
 void ListPanelFunc::rename( const QString &oldname, const QString &newname ) {
-	kdWarning() << "old " << oldname << " new " << newname << endl;
 	if ( oldname == newname )
 		return ; // do nothing
 	panel->view->setNameToMakeCurrent( newname );
@@ -443,7 +450,7 @@ void ListPanelFunc::mkdir() {
 			}
 			// else go into this dir
 			else {
-				openUrl( *it );
+				immediateOpenUrl( *it );
 				continue;
 			}
 		}
@@ -452,7 +459,7 @@ void ListPanelFunc::mkdir() {
 		// as always - the vfs do the job
 		files() ->vfs_mkdir( *it );
 		if ( dirTree.count() > 1 )
-			openUrl( *it );
+			immediateOpenUrl( *it );
 	} // for
 }
 
@@ -462,7 +469,7 @@ void ListPanelFunc::copyFiles() {
 	if ( fileNames.isEmpty() )
 		return ;  // safety
 
-	QString dest = panel->otherPanel->getPath();
+	KURL dest = panel->otherPanel->virtualPath();
 
 	// confirm copy
 	krConfig->setGroup( "Advanced" );
@@ -473,33 +480,24 @@ void ListPanelFunc::copyFiles() {
 		else
 			s.sprintf( i18n( "Copy %d files to:" ).local8Bit(), fileNames.count() );
 		// ask the user for the copy dest
-		KChooseDir *chooser = new KChooseDir( 0, s, panel->otherPanel->getPath() );
-		dest = chooser->dest;
-		if ( dest == QString::null )
-			return ; // the usr canceled
+		dest = KChooseDir::getDir(s, dest, panel->virtualPath());
+		if ( dest.isEmpty() ) return ; // the user canceled
 	}
 
 	KURL::List* fileUrls = files() ->vfs_getFiles( &fileNames );
 
 	// if we are  not copying to the other panel :
-	if ( panel->otherPanel->getPath() != dest ) {
-		bool refresh = false;
-		if ( dest.left( 1 ) != "/" ) {
-			dest = files() ->vfs_workingDir() + "/" + dest;
-			if ( !dest.contains( "/" ) )
-				refresh = true;
-		}
+	if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
 		// you can rename only *one* file not a batch,
 		// so a batch dest must alwayes be a directory
-		if ( ( fileNames.count() > 1 ) && ( dest.right( 1 ) != "/" ) )
-			dest = dest + "/";
-		QDir().mkdir( dest.left( dest.findRev( "/" ) ) );
-		KURL destUrl;
-		destUrl.setPath( dest );
-		KIO::Job* job = new KIO::CopyJob( *fileUrls, destUrl, KIO::CopyJob::Copy, false, true );
-		if ( refresh )
-			connect( job, SIGNAL( result( KIO::Job* ) ), SLOTS, SLOT( refresh() ) );
-		// let the other panel do the dirty job
+		if ( fileNames.count() > 1 ) dest.adjustPath(1);
+		KIO::Job* job = new KIO::CopyJob( *fileUrls, dest, KIO::CopyJob::Copy, false, true );
+		job->setAutoErrorHandlingEnabled( true );
+		if ( dest.equals( panel->virtualPath(), true ) ||
+			dest.upURL().equals( panel->virtualPath(), true ) )
+			// refresh our panel when done
+			connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( refresh() ) );
+	// let the other panel do the dirty job
 	} else {
 		//check if copy is supported
 		if ( !otherFunc() ->files() ->vfs_isWritable() ) {
@@ -511,7 +509,7 @@ void ListPanelFunc::copyFiles() {
 	}
 }
 
-void ListPanelFunc::deleteFiles() {
+void ListPanelFunc::deleteFiles(bool reallyDelete) {
 	// check that the you have write perm
 	if ( !files() ->vfs_isWritable() ) {
 		KMessageBox::sorry( krApp, i18n( "You do not have write permission to this directory" ) );
@@ -524,17 +522,18 @@ void ListPanelFunc::deleteFiles() {
 	if ( fileNames.isEmpty() )
 		return ;
 
+	krConfig->setGroup( "General" );
+	bool trash = krConfig->readBoolEntry( "Move To Trash", _MoveToTrash );
 	// now ask the user if he want to delete:
 	krConfig->setGroup( "Advanced" );
 	if ( krConfig->readBoolEntry( "Confirm Delete", _ConfirmDelete ) ) {
 		QString s, b;
 		if ( fileNames.count() == 1 )
-			s = i18n( " this item ?" );
+			s = i18n( " this item?" );
 		else
-			s.sprintf( i18n( " these %d items ?" ).local8Bit(), fileNames.count() );
-		krConfig->setGroup( "General" );
-		if ( krConfig->readBoolEntry( "Move To Trash", _MoveToTrash ) &&
-		        files() ->vfs_getType() == vfs::NORMAL ) {
+			s.sprintf( i18n( " these %d items?" ).local8Bit(), fileNames.count() );
+		
+		if ( !reallyDelete && trash && files() ->vfs_getType() == vfs::NORMAL ) {
 			s = i18n( "trash" ) + s;
 			b = i18n( "&Trash" );
 		} else {
@@ -557,12 +556,12 @@ void ListPanelFunc::deleteFiles() {
 	for ( QStringList::Iterator name = fileNames.begin(); name != fileNames.end(); ) {
 		vfile * vf = files() ->vfs_search( *name );
 
-		// verify non-empty dirs delete... (only for norml vfs)
+		// verify non-empty dirs delete... (only for normal vfs)
 		if ( emptyDirVerify && vf->vfile_isDir() && !vf->vfile_isSymLink() ) {
-			dir.setPath( panel->getPath() + "/" + ( *name ) );
+			dir.setPath( panel->virtualPath().path() + "/" + ( *name ) );
 			if ( dir.count() > 2 ) {
 				switch ( KMessageBox::warningYesNoCancel( krApp,
-				                                          i18n( "Directory " ) + ( *name ) + i18n( " is not empty !\nSkip this one or Delete All ?" ),
+				                                          i18n( "Directory " ) + ( *name ) + i18n( " is not empty!\nSkip this one or Delete All?" ),
 				                                          QString::null, i18n( "&Skip" ), i18n( "&Delete All" ) ) ) {
 						case KMessageBox::Cancel :
 						return ;
@@ -586,7 +585,16 @@ void ListPanelFunc::deleteFiles() {
 	panel->prepareToDelete();
 
 	// let the vfs do the job...
+	if (reallyDelete) {
+		// if reallyDelete, then make sure nothing gets moved to trash
+		krConfig->setGroup("General");
+		krConfig->writeEntry( "Move To Trash", false );
+	}
 	files() ->vfs_delFiles( &fileNames );
+	if (reallyDelete) {
+		krConfig->setGroup("General");
+		krConfig->writeEntry( "Move To Trash", trash);
+	}
 }
 
 // this is done when you double click on a file
@@ -599,6 +607,7 @@ void ListPanelFunc::execute( QString& name ) {
 	vfile *vf = files() ->vfs_search( name );
 	if ( vf == 0 )
 		return ;
+	
 	KURL origin = files() ->vfs_getOrigin();
 
 	QString protocol = origin.isLocalFile() ? KrServices::registerdProtocol( vf->vfile_getMime() ) : "";
@@ -612,7 +621,6 @@ void ListPanelFunc::execute( QString& name ) {
 	}
 
 	if ( vf->vfile_isDir() ) {
-		//origin.addPath(name);
 		origin = files() ->vfs_getFile( name );
 		panel->view->setNameToMakeCurrent( QString::null );
 		openUrl( origin );
@@ -640,22 +648,22 @@ void ListPanelFunc::pack() {
 		return ; // nothing to pack
 
 	// choose the default name
-	QString defaultName = panel->virtualPath.right( panel->virtualPath.length() - panel->virtualPath.findRev( '/' ) - 1 );
+	QString defaultName = panel->virtualPath().fileName();
 	if ( defaultName == "" )
 		defaultName = "pack";
 	if ( fileNames.count() == 1 )
 		defaultName = fileNames.first();
 	// ask the user for archive name and packer
-	new PackGUI( defaultName, panel->otherPanel->virtualPath, fileNames.count(), fileNames.first() );
+	new PackGUI( defaultName, panel->otherPanel->virtualPath().prettyURL(), fileNames.count(), fileNames.first() );
 	if ( PackGUI::type == QString::null )
 		return ; // the user canceled
 
 	// check for partial URLs	
 	if( !PackGUI::destination.contains(":/") && !PackGUI::destination.startsWith("/")  ){
-		PackGUI::destination = panel->virtualPath+"/"+PackGUI::destination;
+		PackGUI::destination = panel->virtualPath().prettyURL()+"/"+PackGUI::destination;
 	}
 	
-	bool packToOtherPanel = ( PackGUI::destination == panel->otherPanel->virtualPath );
+	bool packToOtherPanel = ( PackGUI::destination == panel->otherPanel->virtualPath().prettyURL() );
 
 	// on remote URL-s first pack into a temp file then copy to its right place
 	KURL destURL = vfs::fromPathOrURL( PackGUI::destination + "/" + PackGUI::filename + "." + PackGUI::type );
@@ -671,11 +679,15 @@ void ListPanelFunc::pack() {
 			( arcFile );
 	}
 
-	if ( PackGUI::type != "zip" && QFileInfo( arcFile ).exists() ) {
-		if ( KMessageBox::warningContinueCancel( krApp,
-		                                         i18n( "The Archive " ) + PackGUI::filename + "." + PackGUI::type +
-		                                         i18n( " already exists, Do you want to overwrite the archive " ) +
-		                                         i18n( "(all data in previous archive will be lost)" ), QString::null, i18n( "&Overwite" ) )
+	if (  QFileInfo( arcFile ).exists() ) {
+		QString msg = i18n( "The Archive " ) + PackGUI::filename + "." + PackGUI::type+
+		              i18n(" already exists. Do you want to overwrite the archive ?\n");
+		if( PackGUI::type == "zip" ){
+			msg = msg + i18n("(ZIP will replace identically named entries in the zip archive or add entries for new names)"); 
+		} else {
+			msg = msg+ ("(all data in previous archive will be lost)");
+		}
+		if ( KMessageBox::warningContinueCancel( krApp,msg,QString::null,i18n( "&Overwrite" ))
 		        == KMessageBox::Cancel )
 			return ; // stop operation
 	}
@@ -688,7 +700,8 @@ void ListPanelFunc::pack() {
 	KIO::filesize_t totalSize = 0;
 	unsigned long totalDirs = 0, totalFiles = 0;
 	for ( QStringList::Iterator file = fileNames.begin(); file != fileNames.end(); ++file ) {
-		files() ->vfs_calcSpace( ( *file ), &totalSize, &totalFiles, &totalDirs );
+		bool stop = false;
+		files() ->vfs_calcSpace( ( *file ), &totalSize, &totalFiles, &totalDirs, &stop );
 	}
 
 	// download remote URL-s if necessary
@@ -758,7 +771,7 @@ void ListPanelFunc::testArchive() {
 	if ( KRarcHandler::test( url, type ) )
 		KMessageBox::information( krApp, i18n( "%1, test passed." ).arg( arcName ) );
 	else
-		KMessageBox::error( krApp, i18n( "%1, test failed !" ).arg( arcName ) );
+		KMessageBox::error( krApp, i18n( "%1, test failed!" ).arg( arcName ) );
 
 	// remove the downloaded file if necessary
 	if ( url != arcURL.path( -1 ) )
@@ -779,16 +792,10 @@ void ListPanelFunc::unpack() {
 		s = i18n( "Unpack " ) + i18n( "%1 files" ).arg( fileNames.count() ) + i18n( "to" ) + ":";
 
 	// ask the user for the copy dest
-	KChooseDir *chooser = new KChooseDir( 0, s, panel->otherPanel->getPath() );
-	QString dest = chooser->dest;
-	if ( dest == QString::null )
-		return ; // the usr canceled
+	KURL dest = KChooseDir::getDir(s, panel->otherPanel->virtualPath(), panel->virtualPath());
+	if ( dest.isEmpty() ) return ; // the user canceled
 
-	// check for partial URLs	
-	if( !dest.contains(":/") && !dest.startsWith("/")  ){
-		dest = panel->virtualPath+"/"+dest;
-	}
-	bool packToOtherPanel = ( dest == panel->otherPanel->virtualPath );
+	bool packToOtherPanel = ( dest.equals( panel->otherPanel->virtualPath(), true ) );
 
 	for ( unsigned int i = 0; i < fileNames.count(); ++i ) {
 		QString arcName = fileNames[ i ];
@@ -810,17 +817,15 @@ void ListPanelFunc::unpack() {
 			url = arcURL.path( -1 );
 
 		// if the destination is in remote directory use temporary one instead
-		if ( !dest.endsWith( "/" ) )
-			dest += "/";
-		KURL destURL = vfs::fromPathOrURL( dest );
+		dest.adjustPath(1);
 		KURL originalDestURL;
 		KTempDir *tempDir = 0;
 
-		if ( !destURL.isLocalFile() ) {
-			originalDestURL = destURL;
+		if ( !dest.isLocalFile() ) {
+			originalDestURL = dest;
 			tempDir = new KTempDir();
 			tempDir->setAutoDelete( true );
-			destURL = tempDir->name();
+			dest = tempDir->name();
 		}
 
 		// determining the type
@@ -835,7 +840,7 @@ void ListPanelFunc::unpack() {
 			continue;
 		}
 		// unpack the files
-		KRarcHandler::unpack( url, type, destURL.path( -1 ) );
+		KRarcHandler::unpack( url, type, dest.path( -1 ) );
 
 		// remove the downloaded file if necessary
 		if ( url != arcURL.path( -1 ) )
@@ -843,11 +848,11 @@ void ListPanelFunc::unpack() {
 
 		// copy files to the destination directory at remote files
 		if ( tempDir ) {
-			QStringList nameList = QDir( destURL.path( -1 ) ).entryList();
+			QStringList nameList = QDir( dest.path( -1 ) ).entryList();
 			KURL::List urlList;
 			for ( unsigned int i = 0; i != nameList.count(); i++ )
 				if ( nameList[ i ] != "." && nameList[ i ] != ".." )
-					urlList.append( vfs::fromPathOrURL( destURL.path( 1 ) + nameList[ i ] ) );
+					urlList.append( vfs::fromPathOrURL( dest.path( 1 ) + nameList[ i ] ) );
 			if ( urlList.count() > 0 )
 				KIO::NetAccess::dircopy( urlList, originalDestURL, 0 );
 			delete tempDir;
@@ -894,13 +899,12 @@ void ListPanelFunc::FTPDisconnect() {
 	if ( files() ->vfs_getType() == vfs::FTP ) {
 		krFTPDiss->setEnabled( false );
 		panel->view->setNameToMakeCurrent( QString::null );
-		openUrl( panel->realPath ); // open the last local URL
+		openUrl( panel->realPath() ); // open the last local URL
 	}
 }
 
 void ListPanelFunc::newFTPconnection() {
-	QString url;
-	url = KRSpWidgets::newFTP();
+	KURL url = KRSpWidgets::newFTP();
 	// if the user canceled - quit
 	if ( url.isEmpty() )
 		return ;
@@ -921,8 +925,8 @@ void ListPanelFunc::properties() {
 		vfile* vf = files() ->vfs_search( names[ i ] );
 		if ( !vf )
 			continue;
-		//KURL url = files()->vfs_getFile( names[i] );
-		fi.append( new KFileItem( vf->vfile_getEntry(), files() ->vfs_getOrigin(), false, true ) );
+		KURL url = files()->vfs_getFile( names[i] );
+		fi.append( new KFileItem( vf->vfile_getEntry(), url ) );
 	}
 
 	if ( fi.isEmpty() )
@@ -937,7 +941,7 @@ void ListPanelFunc::refreshActions() {
 	vfs::VFS_TYPE vfsType = files() ->vfs_getType();
 	//  set up actions
 	krMultiRename->setEnabled( vfsType == vfs::NORMAL );  // batch rename
-	krProperties ->setEnabled( vfsType == vfs::NORMAL || vfsType == vfs::FTP ); // file properties
+	//krProperties ->setEnabled( vfsType == vfs::NORMAL || vfsType == vfs::FTP ); // file properties
 	krFTPDiss ->setEnabled( vfsType == vfs::FTP );     // disconnect an FTP session
 	/*
 	  krUnpack->setEnabled(true);                            // unpack archive
@@ -988,19 +992,15 @@ void ListPanelFunc::copyToClipboard( bool move ) {
 void ListPanelFunc::pasteFromClipboard() {
 	QClipboard * cb = QApplication::clipboard();
 	QMimeSource * data = cb->data();
-	QStringList fileNames;
-	if ( QUriDrag::canDecode( data ) ) {
-		QUriDrag::decodeToUnicodeUris( data, fileNames );
+	KURL::List urls;
+	if ( KURLDrag::canDecode( data ) ) {
+		KURLDrag::decode( data, urls );
 		bool cutSelection = KRDrag::decodeIsCutSelection( data );
 
-		KURL::List* fileUrls = new KURL::List();
-		for ( QStringList::Iterator name = fileNames.begin(); name != fileNames.end(); ++name ) {
-			fileUrls->append( vfs::fromPathOrURL( *name ) );
-		}
+		KURL destUrl = panel->virtualPath();
 
-		KURL destUrl = vfs::fromPathOrURL( panel->getPath() );
-
-		KIO::Job* job = new KIO::CopyJob( *fileUrls, destUrl, cutSelection ? KIO::CopyJob::Move : KIO::CopyJob::Copy, false, true );
+		KIO::Job* job = new KIO::CopyJob( urls, destUrl, cutSelection ? KIO::CopyJob::Move : KIO::CopyJob::Copy, false, true );
+		job->setAutoErrorHandlingEnabled( true );
 		connect( job, SIGNAL( result( KIO::Job* ) ), SLOTS, SLOT( refresh() ) );
 	}
 }
