@@ -29,18 +29,22 @@
  ***************************************************************************/
 
 #include "../krusader.h"
+#include "../defaults.h"
+#include "../panelmanager.h"
 #include "../VFS/vfs.h"
 #include "../krusaderview.h"
 #include "../Panel/listpanel.h"
 #include "../Panel/panelfunc.h"
 #include "../Dialogs/krdialogs.h"
 #include "../VFS/krpermhandler.h"
+#include "../VFS/virt_vfs.h"
 #include "../KViewer/krviewer.h"
 #include "krsearchmod.h"
 #include "krsearchdialog.h"
 
 #include <time.h>
 #include <kglobal.h>
+#include <kinputdialog.h>
 #include <qregexp.h>
 #include <qfontmetrics.h>
 #include <kmessagebox.h>
@@ -50,7 +54,7 @@
 #include <qclipboard.h>
 #include <qheader.h>
 
-QString KrSearchDialog::lastSearchText = "";
+QString KrSearchDialog::lastSearchText = "*";
 int KrSearchDialog::lastSearchType = 0;
 bool KrSearchDialog::lastSearchForCase = false;
 bool KrSearchDialog::lastContainsWholeWord = false;
@@ -81,6 +85,11 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
   buttonsLayout->addItem( spacer );
 
+  mainFeedToListBoxBtn = new QPushButton( this, "mainFeedToListBoxBtn" );
+  mainFeedToListBoxBtn->setText( i18n( "Feed to listbox" ) );
+  mainFeedToListBoxBtn->setEnabled(false);
+  buttonsLayout->addWidget( mainFeedToListBoxBtn );
+  
   mainSearchBtn = new QPushButton( this, "mainSearchBtn" );
   mainSearchBtn->setText( i18n( "Search" ) );
   mainSearchBtn->setDefault(true);
@@ -101,7 +110,8 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   
   searcherTabs = new QTabWidget( this, "searcherTabs" );
 
-  generalFilter = new GeneralFilter( true, searcherTabs, "generalFilter" );
+  generalFilter = new GeneralFilter( HAS_DONT_SEARCH_IN | HAS_SEARCH_IN | HAS_RECURSE_OPTIONS, 
+                                     searcherTabs, "generalFilter" );
   searcherTabs->insertTab( generalFilter, i18n( "&General" ) );
 
   advancedFilter = new AdvancedFilter( searcherTabs, "advancedFilter" );
@@ -180,6 +190,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   connect( resultsList, SIGNAL( doubleClicked(QListViewItem*) ), this, SLOT( resultClicked(QListViewItem*) ) );
   connect( resultsList, SIGNAL( rightButtonClicked(QListViewItem*,const QPoint&,int) ), this, SLOT( rightClickMenu(QListViewItem*, const QPoint&, int) ) );
   connect( mainCloseBtn, SIGNAL( clicked() ), this, SLOT( closeDialog() ) );
+  connect( mainFeedToListBoxBtn, SIGNAL( clicked() ), this, SLOT( feedToListBox() ) );
   
   connect( profileManager, SIGNAL( loadFromProfile( QString ) ), generalFilter, SLOT( loadFromProfile( QString ) ) );
   connect( profileManager, SIGNAL( saveToProfile( QString ) ), generalFilter, SLOT( saveToProfile( QString ) ) );
@@ -224,7 +235,8 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
     generalFilter->searchInDirs->setChecked( lastSearchInSubDirs );
     generalFilter->searchInArchives->setChecked( lastSearchInArchives );
     generalFilter->followLinks->setChecked( lastFollowSymLinks );
-    generalFilter->searchInEdit->setText( ACTIVE_PANEL->getPath() ); // the path in the active panel should be the default search location
+    // the path in the active panel should be the default search location
+    generalFilter->searchIn->lineEdit()->setText( ACTIVE_PANEL->virtualPath().prettyURL() ); 
   }
   else
     profileManager->loadByName( profile ); // important: call this _after_ you've connected profileManager ot the loadFromProfile!!
@@ -319,10 +331,10 @@ bool KrSearchDialog::gui2query() {
 void KrSearchDialog::startSearch() {
   // first, informative messages
   if (generalFilter->searchInArchives->isChecked()) {
-    KMessageBox::information(0, i18n("Since you chose to also search in archives, "
-                                     "note the following limitations:\n"
-                                     "You cannot search for text (grep) while doing"
-                                     " a search that includes archives."), 0, "searchInArchives");
+    KMessageBox::information(this, i18n("Since you chose to also search in archives, "
+                                        "note the following limitations:\n"
+                                        "You cannot search for text (grep) while doing"
+                                        " a search that includes archives."), 0, "searchInArchives");
   }
 
   // prepare the query /////////////////////////////////////////////
@@ -334,7 +346,9 @@ void KrSearchDialog::startSearch() {
   mainSearchBtn->setEnabled(false);
   mainCloseBtn->setEnabled(false);
   mainStopBtn->setEnabled(true);
-  resultsList->clear(); searchingLabel->setText("");
+  mainFeedToListBoxBtn->setEnabled(false);
+  resultsList->clear(); 
+  searchingLabel->setText("");
   foundLabel->setText(i18n("Found 0 matches."));
   searcherTabs->setCurrentPage(2); // show the results page
   qApp->processEvents();
@@ -370,6 +384,8 @@ void KrSearchDialog::stopSearch() {
   mainSearchBtn->setEnabled(true);
   mainCloseBtn->setEnabled(true);
   mainStopBtn->setEnabled(false);
+  if( resultsList->childCount() )
+    mainFeedToListBoxBtn->setEnabled( true );
   searchingLabel->setText(i18n("Finished searching."));
 }
 
@@ -474,4 +490,46 @@ void KrSearchDialog::rightClickMenu(QListViewItem *item, const QPoint&, int)
   }
 }
 
+void KrSearchDialog::feedToListBox()
+{
+  virt_vfs v(0,true);
+  v.vfs_refresh( KURL( "/" ) );
+  
+  krConfig->setGroup( "Search" );  
+  int listBoxNum = krConfig->readNumEntry( "Feed To Listbox Counter", 1 );  
+  QString queryName;
+  do {
+    queryName = i18n("Search results")+QString( " %1" ).arg( listBoxNum++ );
+  }while( v.vfs_search( queryName ) != 0 );
+  krConfig->writeEntry( "Feed To Listbox Counter", listBoxNum );  
+  
+  krConfig->setGroup( "Advanced" );
+  if ( krConfig->readBoolEntry( "Confirm Feed to Listbox",  _ConfirmFeedToListbox ) ) {
+    bool ok;
+    queryName = KInputDialog::getText(
+                i18n("Query name"),		// Caption
+                i18n("Here you can name the file collection"),	// Questiontext
+                queryName,	// Default
+                &ok );
+     if ( ! ok)
+       return;
+  }
+  
+  KURL::List urlList;
+  QListViewItem * item = resultsList->firstChild();
+  while( item )
+  {
+    QString name = item->text(1);
+    name += (name.endsWith( "/" ) ? item->text(0) : "/" + item->text(0) );
+    urlList.push_back( vfs::fromPathOrURL( name ) );
+    item = item->nextSibling();
+  }
+  KURL url = KURL::fromPathOrURL( QString("virt:/") + queryName );
+  v.vfs_refresh( url );
+  v.vfs_addFiles( &urlList, KIO::CopyJob::Copy, 0 );
+  //ACTIVE_FUNC->openUrl(url);  
+  ACTIVE_MNG->slotNewTab(url.prettyURL());
+  closeDialog();
+}
+
 #include "krsearchdialog.moc"
