@@ -48,7 +48,15 @@
 #include <unistd.h>
 #include <qeventloop.h>
 #include <qprogressdialog.h>
+#include <qpushbutton.h>
 #include <kprocess.h>
+#include <kdialogbase.h>
+#include <kprogress.h>
+#include <qlayout.h>
+
+#include <sys/types.h>
+#include <sys/time.h>
+#include <utime.h>
 
 #define  DISPLAY_UPDATE_PERIOD        2
 
@@ -93,6 +101,11 @@ int Synchronizer::compare( QString leftURL, QString rightURL, KRQuery *query, bo
   if( !leftURL.endsWith("/" ))  leftURL+="/";
   if( !rightURL.endsWith("/" )) rightURL+="/";
 
+  excludedPaths = query->whereNotToSearch.toStringList();
+  for( int i = 0; i != excludedPaths.count(); i++ )
+    if( excludedPaths[ i ].endsWith( "/" ) )
+      excludedPaths[ i ].truncate( excludedPaths[ i ].length() - 1 );
+  
   scannedDirs = fileCount = 0;
   
   compareDirectory( 0, leftBaseDir = leftURL, rightBaseDir = rightURL, "", "" );
@@ -178,6 +191,9 @@ void Synchronizer::compareDirectory( SynchronizerFileItem *parent, QString leftU
       {
         QString left_file_name =  left_file->vfile_getName();
         
+        if( excludedPaths.contains( leftDir.isEmpty() ? left_file_name : leftDir+"/"+left_file_name ) )
+          continue;
+
         if( (right_file = searchFile( right_directory, left_file_name )) == 0 )
           addSingleDirectory( parent, left_file_name, leftDir, left_file->vfile_getTime_t(), true, !query->match( left_file ) );
         else
@@ -201,6 +217,9 @@ void Synchronizer::compareDirectory( SynchronizerFileItem *parent, QString leftU
       {
         file_name =  right_file->vfile_getName();
 
+        if( excludedPaths.contains( rightDir.isEmpty() ? file_name : rightDir+"/"+file_name ) )
+          continue;
+
         if( searchFile( left_directory, file_name ) == 0 )
           addSingleDirectory( parent, file_name, rightDir, right_file->vfile_getTime_t(), false, !query->match( right_file ) );
       }
@@ -397,6 +416,10 @@ void Synchronizer::addSingleDirectory( SynchronizerFileItem *parent, QString nam
     if ( file->vfile_isDir() && (followSymLinks || !file->vfile_isSymLink())  )
     {
         file_name =  file->vfile_getName();
+        
+        if( excludedPaths.contains( dirName.isEmpty() ? file_name : dirName+"/"+file_name ) )
+          continue;
+
         addSingleDirectory( parent, file_name, dirName, file->vfile_getTime_t(), isLeft, !query->match( file ) );
     }
   }
@@ -811,7 +834,37 @@ void Synchronizer::executeTask()
 void Synchronizer::slotTaskFinished(KIO::Job *job )
 {
   do {
-    if( job->error() )
+    if( !job->error() )
+    {
+      switch( currentTask->task() )
+      {
+      case TT_COPY_TO_LEFT:
+        if( leftURL.isLocalFile() )
+        {
+          struct utimbuf timestamp;
+
+          timestamp.actime = time( 0 );
+          timestamp.modtime = currentTask->rightDate();
+
+          utime( (const char *)( leftURL.path( -1 ).local8Bit() ), &timestamp );
+        }
+        break;
+      case TT_COPY_TO_RIGHT:
+        if( rightURL.isLocalFile() )
+        {
+          struct utimbuf timestamp;
+
+          timestamp.actime = time( 0 );
+          timestamp.modtime = currentTask->leftDate();
+
+          utime( (const char *)( rightURL.path( -1 ).local8Bit() ), &timestamp );
+        }
+        break;
+      default:
+        break;
+      }
+    }
+    else
     {
       if( job->error() == KIO::ERR_FILE_ALREADY_EXIST && currentTask->task() != TT_DELETE )
       {
@@ -1141,8 +1194,57 @@ void Synchronizer::comparePercent(KIO::Job *, unsigned long percent)
 
 void Synchronizer::synchronizeWithKGet()
 {
+  class KgetProgressDialog : public KDialogBase
+  {
+  public:
+    KgetProgressDialog( QWidget *parent=0, const char *name=0, const QString &caption=QString::null, 
+                      const QString &text=QString::null, bool modal=false) : KDialogBase( KDialogBase::Plain, 
+                      caption, KDialogBase::User1 | KDialogBase::Cancel, KDialogBase::Cancel, parent, name, modal )
+    {
+      showButton(KDialogBase::Close, false);
+      
+      QFrame* mainWidget = plainPage();
+      QVBoxLayout* layout = new QVBoxLayout(mainWidget, 10);
+
+      QLabel *mLabel = new QLabel(text, mainWidget);
+      layout->addWidget(mLabel);
+
+      mProgressBar = new KProgress(mainWidget);
+      layout->addWidget(mProgressBar);
+      
+      setButtonText( KDialogBase::User1, i18n( "Pause" ) );
+      
+      mCancelled = mPaused = false;
+    }
+    
+    KProgress *progressBar() { return mProgressBar; }
+ 
+    void slotUser1()
+    {
+      if( ( mPaused = !mPaused ) == false )
+        setButtonText( KDialogBase::User1, i18n( "Pause" ) );
+      else
+        setButtonText( KDialogBase::User1, i18n( "Resume" ) );          
+    }
+    
+    void slotCancel()
+    {
+      mCancelled = true;
+
+      KDialogBase::slotCancel();
+    }
+    
+    bool wasCancelled()      { return mCancelled; }
+    bool isPaused()          { return mPaused; }
+    
+  private:
+    KProgress *mProgressBar;
+    bool       mCancelled;
+    bool       mPaused;
+  };  
+
   bool isLeftLocal = vfs::fromPathOrURL( leftBaseDirectory() ).isLocalFile();
-  QProgressDialog *progDlg = 0;
+  KgetProgressDialog *progDlg = 0;
   int  processedCount = 0, totalCount = 0;
   
   SynchronizerFileItem *item = resultList.first();  
@@ -1162,10 +1264,9 @@ void Synchronizer::synchronizeWithKGet()
       
       if( progDlg == 0 )
       {
-        progDlg = new QProgressDialog( i18n( "Feeding the URL-s to kget" ), i18n("Cancel"), 
-                     totalCount, krApp, "Synchronizer Progress Dlg", true );
-        progDlg->setCaption( i18n( "Krusader::Synchronizer" ) );
-        progDlg->setAutoClose( false );
+        progDlg = new KgetProgressDialog( krApp, "Synchronizer Progress Dlg", i18n("Krusader::Synchronizer"), 
+                                          i18n( "Feeding the URLs to Kget" ), true );
+        progDlg->progressBar()->setTotalSteps( totalCount );
         progDlg->show();
         qApp->processEvents();
       }
@@ -1218,12 +1319,23 @@ void Synchronizer::synchronizeWithKGet()
           p.detach();
       }
       
-      progDlg->setProgress( ++processedCount );
-      qApp->processEvents();
+      progDlg->progressBar()->setProgress( ++processedCount );
       
-      if( progDlg->wasCanceled() )
+      do
+      {      
+        qApp->processEvents();
+      
+        if( progDlg->wasCancelled() )
+          break;
+          
+        if( progDlg->isPaused() )
+          usleep( 100000 );
+          
+      }while( progDlg->isPaused() );
+    
+      if( progDlg->wasCancelled() )
         break;
-    }
+    }      
     item = resultList.next();
   }
   
