@@ -43,6 +43,7 @@
 #include <kglobalsettings.h>
 #include <kdebug.h>
 #include <klargefile.h>
+#include <kfileitem.h>
 // Krusader includes
 #include "normal_vfs.h"
 #include "../Dialogs/krdialogs.h"
@@ -51,6 +52,7 @@
 #include "../krusader.h"
 #include "../defaults.h"
 #include "../resources.h"
+#include "../krslots.h"
 
 normal_vfs::normal_vfs(QObject* panel):vfs(panel), watcher(0) {
   setVfsFilesP(&vfs_files);
@@ -61,7 +63,7 @@ normal_vfs::normal_vfs(QObject* panel):vfs(panel), watcher(0) {
 
 bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 	QString path = origin.path(-1);
-		
+	
 	// set the writable attribute to true, if that's not the case - the KIO job
 	// will give the warnings and errors
 	isWritable = true;
@@ -71,8 +73,9 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 
 	// set the origin...
 	vfs_origin = origin;
+	vfs_origin.adjustPath(-1);
 	vfs_origin.setProtocol("file"); // do not remove !
-	vfs_origin.cleanPath();
+	vfs_origin.cleanPath(-1);
 	
 	// check that the new origin exists
 	if ( !QDir(path).exists() )
@@ -85,7 +88,7 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 	if (krConfig->readBoolEntry("AutoMount",_AutoMount)) krMtMan.autoMount(path);
 	
 	krConfig->setGroup("General");
-	bool mtm    = krConfig->readBoolEntry("Mimetype Magic",_MimetypeMagic);
+	bool mtm    = !mimeTypeMagicDisabled && krConfig->readBoolEntry("Mimetype Magic",_MimetypeMagic);
 
 	DIR* dir = opendir(path.local8Bit());
 	if(!dir) 
@@ -140,6 +143,8 @@ void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,Q
   connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()) );
   if(mode == KIO::CopyJob::Move) // notify the other panel
     connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(vfs_refresh(KIO::Job*)) );
+  else
+    job->setAutoErrorHandlingEnabled( true );
 }
 
 // remove a file from the vfs (physical)
@@ -163,8 +168,12 @@ void normal_vfs::vfs_delFiles(QStringList *fileNames){
 	// delete of move to trash ?
 	krConfig->setGroup("General");
 	if( krConfig->readBoolEntry("Move To Trash",_MoveToTrash) ){
+#if KDE_IS_VERSION(3,4,0)
+	  job = KIO::trash(filesUrls, true );
+#else
 	  job = new KIO::CopyJob(filesUrls,KGlobalSettings::trashPath(),KIO::CopyJob::Move,false,true );
-	  connect(job,SIGNAL(result(KIO::Job*)),krApp,SLOT(changeTrashIcon()));
+#endif
+	  connect(job,SIGNAL(result(KIO::Job*)),SLOTS,SLOT(changeTrashIcon()));
 	}
 	else
 	  job = new KIO::DeleteJob(filesUrls, false, true);
@@ -191,7 +200,7 @@ KURL::List* normal_vfs::vfs_getFiles(QStringList* names){
 
 void normal_vfs::vfs_mkdir(const QString& name){
 	if (!QDir(vfs_workingDir()).mkdir(name))
-	  if (!quietMode) KMessageBox::sorry(krApp,i18n("Can't create a directory check your permissions."));
+	  if (!quietMode) KMessageBox::sorry(krApp,i18n("Can't create a directory. Check your permissions."));
   vfs::vfs_refresh();
 }
 
@@ -210,19 +219,19 @@ void normal_vfs::vfs_rename(const QString& fileName,const QString& newName){
 }
 
 void normal_vfs::vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool* stop){
-  if (stop && *stop) return;
+  if ( *stop ) return;
   if (!name.contains("/")) name = vfs_workingDir()+"/"+name;
   if (name == "/proc") return;
 
-  QFileInfo qfi(name);
-  if(qfi.isSymLink() || !qfi.isDir()){ // single files are easy : )
+  KFileItem kfi( KFileItem::Unknown, KFileItem::Unknown, vfs::fromPathOrURL( name ) );
+  if(kfi.isLink() || !kfi.isDir()){ // single files are easy : )
     ++(*totalFiles);
-    (*totalSize) += qfi.size();
+    (*totalSize) += kfi.size();
   }
   else{  // handle directories
 		QDir dir(name);
     // avoid a nasty crash on un-readable dirs
-		if ( !qfi.isReadable() || !dir.exists() ) return;
+		if ( !kfi.isReadable() || !dir.exists() ) return;
 		++(*totalDirs);
     dir.setFilter(QDir::All|QDir::Hidden);
 	  dir.setSorting(QDir::Name|QDir::DirsFirst);
@@ -230,7 +239,7 @@ void normal_vfs::vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned
 	  // recurse on all the files in the directory
 	  QFileInfoList* fileList = const_cast<QFileInfoList*>(dir.entryInfoList());
 	  for (QFileInfo* qfiP = fileList->first(); qfiP != 0; qfiP = fileList->next()){
-      if (stop && *stop) return;
+      if ( *stop ) return;
       if (qfiP->fileName() != "." && qfiP->fileName() != "..")
 	      vfs_calcSpace(name+"/"+qfiP->fileName(),totalSize,totalFiles,totalDirs,stop);
 	  }
@@ -259,12 +268,13 @@ vfile* normal_vfs::vfileFromName(const QString& name,bool mimeTypeMagic){
 			if ( QDir(QString::fromLocal8Bit( symDest ) ).exists() || mime.contains("directory") ) perm[0] = 'd';
 			if ( !QDir(vfs_workingDir()).exists( QString::fromLocal8Bit ( symDest ) ) ) mime = "Broken Link !";
 		}
-		else kdWarning() << "Failed to read link: "<< path<<endl;
+		else krOut << "Failed to read link: "<< path<<endl;
 	}
 	
 	// create a new virtual file object
 	vfile* temp=new vfile(name,size,perm,stat_p.st_mtime,symLink,stat_p.st_uid,
                           stat_p.st_gid,mime,symDest,stat_p.st_mode);
+	temp->vfile_setUrl( mimeUrl );
 	return temp;
 }
 
