@@ -29,6 +29,8 @@
 *                                                                         *
 ***************************************************************************/
 
+#include <kglobalsettings.h>
+
 ///////////////////////   [Startup]
 // UI Save Settings
 #define _UiSave           false 
@@ -68,7 +70,7 @@
 
 ////////////////////////[Look&Feel]
 // Filelist Font ///////
-#define _FilelistFont   new QFont("helvetica",11) 
+#define _FilelistFont   new QFont(KGlobalSettings::generalFont())
 // Warn On Exit ////////
 #define _WarnOnExit     false 
 // Minimize To Tray ////
@@ -102,9 +104,9 @@
 // cd other panel is turned on
 #define _cdOther            false 
 // Open directory is turned on
-#define _Open               true 
+#define _Open               false 
 // syncBrowseButton is turned on
-#define _syncBrowseButton   true 
+#define _syncBrowseButton   false 
 // Use the default colors of KDE
 #define _KDEDefaultColors     true 
 // Enable Alternate Background colors
@@ -185,12 +187,6 @@
 #define _TestBeforeUnpack	true 
 // Supported Packers // ====> a QStringList of SYSTEM supported archives ( also new )
 
-/////////////////////// [Bookmarks]
-// Links //////////////
-// the basic link (/) is defined internally
-// Sorted /////////////
-#define _Sorted        true
-
 /////////////////////// [Private]
 // Start Position /////
 #define _StartPosition new QPoint(QApplication::desktop()->width()/2 - mainView->sizeHint().width()/2,QApplication::desktop()->height()/2 - 250) 
@@ -215,6 +211,9 @@
 /////////////////////// [Search]
 // Saved Searches /////
 // holds an index of saved searches
+// Confirm Feed to Listbox ///// (costum-name on feed ti listbox)
+#define _ConfirmFeedToListbox   true
+
 
 /////////// here are additional variables used internally by Krusader ////////////
 // BookmarkArchives   - The infobox about not allowing bookmarks inside archives
@@ -224,6 +223,9 @@
 // lastHomeLeft       - Save the last place the left list panel was showing
 // lastUsedPacker     - used by packGUI to remember the last used packer
 
+/////////////////////// [Popular Urls]
+// PopularUrls     - a string list containing the top urls
+// PopularUrlsRank - an int list contains the urls' ranking
 
 /////////////////////// [Synchronize directories]
 // Don't overwrite automatically /////////////
@@ -257,3 +259,26 @@
 // The singles button is turned on /////////////
 #define  _BtnSingles        true
 
+/////////////////////// [Custom Selection Mode]
+// QT Selection
+#define _QtSelection			false
+// Left Selects
+#define _LeftSelects			true
+// Left Preserves
+#define _LeftPreserves		false
+// ShiftCtrl Left Selects
+#define _ShiftCtrlLeft		false
+// Right Selects
+#define _RightSelects		true
+// Right Preserves
+#define _RightPreserves		false
+// ShiftCtrl Right Selects
+#define _ShiftCtrlRight		false
+// Space Moves Down
+#define _SpaceMovesDown		true
+// Space Calc Space
+#define _SpaceCalcSpace		true
+// Insert Moves Down
+#define _InsertMovesDown	true
+// Immediate Context Menu
+#define _ImmediateContextMenu	true
