@@ -46,11 +46,17 @@
 #include <kdeversion.h>
 #include <kcmdlineargs.h>
 #include <KViewer/krviewer.h>
+
+#ifdef __KJSEMBED__
+#include <kjsembed/jsconsolewidget.h>
+#endif
+
 // Krusader includes
 #include "krslots.h"
 #include "krusader.h"
 #include "krusaderview.h"
 #include "Panel/listpanel.h"
+#include "Panel/krselectionmode.h"
 #include "Dialogs/krdialogs.h"
 #include "Dialogs/krspwidgets.h"
 #include "GUI/krusaderstatus.h"
@@ -62,7 +68,8 @@
 #include "resources.h"
 #include "GUI/kfnkeys.h"
 #include "GUI/kcmdline.h"
-#include "Search/krquery.h"
+#include "GUI/syncbrowsebutton.h"
+#include "VFS/krquery.h"
 #include "Search/krsearchmod.h"
 #include "Search/krsearchdialog.h"
 #include "Locate/locate.h"
@@ -90,7 +97,7 @@ void KRslots::sendFileByEmail(QString filename) {
   QStringList lst = Krusader::supportedTools();
   if (lst.contains("MAIL")) mailProg=lst[lst.findIndex("MAIL") + 1];
   else {
-    KMessageBox::error(0,i18n("Krusader can't find any of the supported mail clients. Please install one to your path. Hint: Krusader supports kmail."));
+    KMessageBox::error(0,i18n("Krusader can't find a supported mail client. Please install one to your path. Hint: Krusader supports Kmail."));
     return;
   }
 
@@ -173,7 +180,7 @@ void KRslots::compareContent( KURL url1, KURL url2 )
   QStringList lst = Krusader::supportedTools();
   if (lst.contains("DIFF")) diffProg=lst[lst.findIndex("DIFF") + 1];
   else {
-    KMessageBox::error(0,i18n("Krusader can't find any of the supported diff-frontends. Please install one to your path. Hint: Krusader supports kompare, kdiff3, kdiff and xxdiff."));
+    KMessageBox::error(0,i18n("Krusader can't find any of the supported diff-frontends. Please install one to your path. Hint: Krusader supports Kompare, Kdiff3 and Xxdiff."));
     return;
   }
 
@@ -211,10 +218,7 @@ void KRslots::rightclickMenu() {
 }
 
 void KRslots::addBookmark(){
-  QString path=ACTIVE_PANEL->virtualPath;
-  if (path.contains('\\')>0)
-    KMessageBox::information(0, i18n("In order to save the time needed to enter an archive, Krusader will not allow bookmarks which point into an archive, as it is usually a mistake to do so!"),
-                             QString::null, "BookmarkArchives");
+	// TODO: this no longer works!
 }
 
 // GUI toggle slots
@@ -234,6 +238,13 @@ void KRslots::toggleToolbar() {
 	else krApp->toolBar()->show();
 }
 
+void KRslots::toggleActionsToolbar() {
+  if (krApp->toolBar("actionsToolBar")->isVisible())
+		krApp->toolBar("actionsToolBar")->hide();
+	else krApp->toolBar("actionsToolBar")->show();
+}
+
+
 void KRslots::toggleStatusbar() {
   if (krApp->statusBar()->isVisible())
 		krApp->statusBar()->hide();
@@ -245,11 +256,6 @@ void KRslots::toggleTerminal() {
   else MAIN_VIEW->slotTerminalEmulator(true);
 }
 
-void KRslots::showAboutApplication() {
-  KRAbout *q=new KRAbout();
-  q->exec();
-}
-
 void KRslots::insertFileName(bool full_path)
 {
   QString filename = ACTIVE_PANEL->view->getCurrentItem();
@@ -274,12 +280,12 @@ void KRslots::customFilter()		{	ACTIVE_PANEL->setFilter(KrViewProperties::Custom
 void KRslots::markAll()         { ACTIVE_PANEL->select(true,true);           }
 void KRslots::unmarkAll()       { ACTIVE_PANEL->select(false,true);          }
 void KRslots::markGroup()       { ACTIVE_PANEL->select(true,false);          }
-void KRslots::markGroup(const QString& mask, bool select) { ACTIVE_PANEL->select(mask, select); }
+void KRslots::markGroup(const QString& mask, bool select) { ACTIVE_PANEL->select( KRQuery( mask ), select); }
 void KRslots::unmarkGroup()     { ACTIVE_PANEL->select(false,false);         }
 void KRslots::invert()          { ACTIVE_PANEL->invertSelection();           }
 
 void KRslots::root()            { ACTIVE_FUNC->openUrl(vfs::fromPathOrURL("/"));}
-void KRslots::refresh(const KURL& u){ ACTIVE_FUNC->delayedOpenUrl(u);        }
+void KRslots::refresh(const KURL& u){ ACTIVE_FUNC->openUrl(u);        }
 void KRslots::home()            { ACTIVE_FUNC->openUrl(QDir::homeDirPath()); }
 void KRslots::refresh()         { ACTIVE_FUNC->refresh();                    }
 void KRslots::properties()      { ACTIVE_FUNC->properties();                 }
@@ -309,9 +315,10 @@ void KRslots::runKonfigurator(bool firstTime) {
     if((krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt() != size )
       QPixmapCache::clear();
 
-    MAIN_VIEW->leftMng->recreatePanels();
-    MAIN_VIEW->rightMng->recreatePanels();
-	 MAIN_VIEW->fnKeys->updateShortcuts();
+    MAIN_VIEW->leftMng->slotRecreatePanels();
+    MAIN_VIEW->rightMng->slotRecreatePanels();
+	  MAIN_VIEW->fnKeys->updateShortcuts();
+		KrSelectionMode::resetSelectionHandler();
   }
   
   delete konfigurator;
@@ -326,8 +333,16 @@ void KRslots::toggleHidden(){
 }
 
 void KRslots::toggleSwapPanels(){
+  QValueList<int> lst = MAIN_VIEW->horiz_splitter->sizes();
+
   MAIN_VIEW->horiz_splitter->moveToLast( MAIN_VIEW->leftMng );
 
+  int old = lst[ 0 ];
+  lst[ 0 ] = lst [ 1 ];
+  lst[ 1 ] = old;
+  
+  MAIN_VIEW->horiz_splitter->setSizes( lst );
+  
   ListPanel     *tmpPanel;     // temporary variables for swapping
   PanelManager  *tmpMng;
 
@@ -425,7 +440,7 @@ void KRslots::multiRename(){
 	QStringList lst = Krusader::supportedTools();
 	int i = lst.findIndex("RENAME");
 	if (i == -1){
-  	KMessageBox::sorry(krApp,i18n("Can't find a batch renamer tool.\nYou can get Krename at http://www.krename.net"));
+  	KMessageBox::sorry(krApp,i18n("Can't find a batch rename tool.\nYou can get Krename at http://www.krename.net"));
   	return;
 	}
 	QString pathToRename = lst[i+1];
@@ -503,50 +518,42 @@ void KRslots::moveFiles()      { ACTIVE_FUNC->moveFiles();  }
 // F7
 void KRslots::mkdir()          { ACTIVE_FUNC->mkdir();      }
 // F8
-void KRslots::deleteFiles()    { ACTIVE_FUNC->deleteFiles();}     	
+void KRslots::deleteFiles(bool reallyDelete)    { ACTIVE_FUNC->deleteFiles(reallyDelete);}     	
 // F9
 void KRslots::rename()         { ACTIVE_FUNC->rename();     }
 
 // Shift F3
 void KRslots::viewDlg(){
   // ask the user for a url to view
-  KChooseDir *chooser = new KChooseDir( 0,i18n("Enter a URL to view:"), QString::null);
-  QString dest = chooser->dest;
-  if ( dest == QString::null ) return ; // the usr canceled
-  else
-  {
-    /* vfs::fromPathOrURL requires fullpath, so we check whether it is relative  */
-    if ( !dest.contains( ":/" ) && !dest.startsWith( "/" ) )
-      dest = ACTIVE_FUNC->files()->vfs_getOrigin().prettyURL(1)+dest; /* it's full path now */
-    
-    KrViewer::view( vfs::fromPathOrURL(dest) ); // view the file
-  }
+	KURL dest = KChooseDir::getDir(i18n("Enter a URL to view:"), ACTIVE_PANEL->virtualPath(), ACTIVE_PANEL->virtualPath());
+	if ( dest.isEmpty() ) return ; // the user canceled
+   
+    KrViewer::view( dest ); // view the file
+//  }
   // nothing more to it!
 }
 
 // Shift F4
 void KRslots::editDlg(){
   // ask the user for the filename to edit
-  KChooseDir *chooser = new KChooseDir( 0,i18n("Enter the filename to edit:"), QString::null);
-  QString dest = chooser->dest;
-  if ( dest == QString::null ) return ; // the usr canceled
-  else
-  {
-    /* vfs::fromPathOrURL requires fullpath, so we check whether it is relative  */
-    if ( !dest.contains( ":/" ) && !dest.startsWith( "/" ) )
-      dest = ACTIVE_FUNC->files()->vfs_getOrigin().prettyURL(1) + dest; /* it's full path now */
+	KURL dest = KChooseDir::getDir(i18n("Enter the filename to edit:"), ACTIVE_PANEL->virtualPath(), ACTIVE_PANEL->virtualPath());
+	if ( dest.isEmpty() ) return ; // the user canceled
 
-    KrViewer::edit( vfs::fromPathOrURL( dest ), true );
-  }
-  // nothing more to it!
+    KrViewer::edit( dest, true );
+    
+    if( dest.upURL().equals( ACTIVE_PANEL->virtualPath(), true ) )
+      refresh();
 }
 
 void KRslots::duplicateTab() {
-  ACTIVE_PANEL_MANAGER->slotNewTab(ACTIVE_PANEL->virtualPath);
+  ACTIVE_PANEL_MANAGER->slotNewTab(ACTIVE_PANEL->virtualPath());
 }
 
-void KRslots::newTab() {
-  ACTIVE_PANEL_MANAGER->slotNewTab();
+// ugly: do this right before release!
+void KRslots::newTab(const KURL& url) {
+  if (url.isValid())
+     ACTIVE_PANEL_MANAGER->slotNewTab(url);
+  else ACTIVE_PANEL_MANAGER->slotNewTab();
 }
 
 void KRslots::nextTab() {
@@ -561,8 +568,9 @@ void KRslots::newTab(QListViewItem *item) {
   if (!item) return;
   KrViewItem *it = dynamic_cast<KrViewItem*>(item);
   if (it->isDir()) {
-    ACTIVE_PANEL_MANAGER->slotNewTab(ACTIVE_PANEL->virtualPath + "/" + it->name());
-    //kdWarning() << ACTIVE_PANEL->virtualPath << it->name()<<endl;
+    KURL url = ACTIVE_PANEL->virtualPath();
+    url.addPath( it->name() );
+    ACTIVE_PANEL_MANAGER->slotNewTab( url );
   }
 }
 
@@ -601,7 +609,7 @@ void KRslots::slotSplit()
 
   if( splitterGUI.result() == QDialog::Accepted )
   {
-    bool splitToOtherPanel = ( splitterGUI.getDestinationDir() == ACTIVE_PANEL->otherPanel->virtualPath );
+    bool splitToOtherPanel = ( vfs::fromPathOrURL( splitterGUI.getDestinationDir() ).equals( ACTIVE_PANEL->otherPanel->virtualPath(), true ) );
 
     Splitter split( MAIN_VIEW, fileName, splitterGUI.getDestinationDir() );
     split.split( splitterGUI.getSplitSize() );
@@ -611,10 +619,9 @@ void KRslots::slotSplit()
   }
 }
 
-void KRslots::slotCombine()
-{
+void KRslots::slotCombine(){
   QStringList   list;
-  QString       fileName;
+  KURL          baseURL;
   bool          unixStyle = false;
   bool          windowsStyle = false;
   QString       commonName = QString::null;
@@ -630,8 +637,8 @@ void KRslots::slotCombine()
   /* checking splitter names */
   for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
   {
-    QString name = ACTIVE_FUNC->files()->vfs_getFile(*it).prettyURL(-1,KURL::StripFileProtocol);
-    if( name == QString::null )
+    KURL url = ACTIVE_FUNC->files()->vfs_getFile(*it);
+    if( url.isEmpty() )
       return;
 
     if ( ACTIVE_FUNC->files()->vfs_search( *it )->vfile_isDir() ) {
@@ -641,9 +648,12 @@ void KRslots::slotCombine()
 
     if( !unixStyle )
     {
+      QString name = url.fileName();
       int extPos = name.findRev( '.' );
-
       QString ext = name.mid( extPos + 1 );
+      name.truncate( extPos );
+      url.setFileName( name );
+      
       bool isExtInt;
       ext.toInt( &isExtInt, 10 );
 
@@ -651,23 +661,22 @@ void KRslots::slotCombine()
       {
         if( windowsStyle )
         {
-          KMessageBox::error(0,i18n("Not a splitted file %1!").arg( name ));
+          KMessageBox::error(0,i18n("Not a split file %1!").arg( url.prettyURL(0, KURL::StripFileProtocol ) ));
           return;
         }
         unixStyle = true;
       }
       else
       {
-        name.truncate( extPos );
 
         if( ext != "crc" )
           windowsStyle = true;
 
-        if( fileName.isEmpty() )
-           fileName = name;
-        else if( fileName != name )
+        if( baseURL.isEmpty() )
+           baseURL = url;
+        else if( baseURL != url )
         {
-          KMessageBox::error(0,i18n("Select only one splitted file!"));
+          KMessageBox::error(0,i18n("Select only one split file!"));
           return;
         }
       }
@@ -701,7 +710,8 @@ void KRslots::slotCombine()
               else
               {
                 commonName = shorter;
-                fileName = ACTIVE_FUNC->files()->vfs_getOrigin().prettyURL(1,KURL::StripFileProtocol) + testFile;
+                baseURL = ACTIVE_FUNC->files()->vfs_getOrigin();
+                baseURL.addPath( testFile );
               }
             }
 
@@ -714,22 +724,20 @@ void KRslots::slotCombine()
 
       if( error )
       {
-        KMessageBox::error(0,i18n("Not a splitted file %1!").arg( name ));
+        KMessageBox::error(0,i18n("Not a splitted file %1!").arg( url.prettyURL(0, KURL::StripFileProtocol ) ));
         return;
       }
     }
   }
 
-  // ask the user for the copy dest
-  KChooseDir *chooser = new KChooseDir( 0, i18n( "Combining %1.* to directory:" ).arg( fileName ),
-                                        ACTIVE_PANEL->otherPanel->getPath() );
-  QString dest = chooser->dest;
-  if ( dest == QString::null )
-    return ; // the usr canceled
+   // ask the user for the copy dest
+  KURL dest = KChooseDir::getDir(i18n("Combining %1.* to directory:" ).arg( baseURL.prettyURL( 0, KURL::StripFileProtocol ) ),
+                                 ACTIVE_PANEL->otherPanel->virtualPath(), ACTIVE_PANEL->virtualPath());
+  if ( dest.isEmpty() ) return ; // the user canceled
 
-  bool combineToOtherPanel = ( dest == ACTIVE_PANEL->otherPanel->virtualPath );
+  bool combineToOtherPanel = ( dest.equals( ACTIVE_PANEL->otherPanel->virtualPath(), true ) );
 
-  Combiner combine( MAIN_VIEW, fileName, dest, unixStyle );
+  Combiner combine( MAIN_VIEW, baseURL, dest, unixStyle );
   combine.combine();
 
   if ( combineToOtherPanel )
@@ -742,8 +750,12 @@ void KRslots::userMenu() {
   krApp->userMenu->exec();
 }
 
+void KRslots::manageUseractions() {
+   Konfigurator konfigurator( false, 7 ); // page 7 are the UserActions
+}
+
 void KRslots::slotSynchronizeDirs() {
-  SynchronizerGUI *sync = new SynchronizerGUI( MAIN_VIEW,
+  SynchronizerGUI *sync = new SynchronizerGUI( krApp,
                 MAIN_VIEW->left->func->files()->vfs_getOrigin().prettyURL(0,KURL::StripFileProtocol),
                 MAIN_VIEW->right->func->files()->vfs_getOrigin().prettyURL(0,KURL::StripFileProtocol) );
 
@@ -754,6 +766,10 @@ void KRslots::slotSynchronizeDirs() {
     REFRESH_BOTH_PANELS;
 }
 
+void KRslots::slotSyncBrowse() {
+   ACTIVE_PANEL->syncBrowseButton->toggle();
+}
+
 void KRslots::updatePopupPanel(QListViewItem *it) {
 	// which panel to display on?
 	ListPanel *lp = 0;
@@ -810,5 +826,11 @@ void KRslots::windowInactive() {
 	MAIN_VIEW->right->panelInactive();
 }
 
+//shows the JavaScript-Console
+void KRslots::jsConsole() {
+#ifdef __KJSEMBED__
+    krJS->view()->show();
+#endif
+}
 
 #include "krslots.moc"
