@@ -52,7 +52,7 @@ class KRslots : public QObject {
   public:
     enum compareMode { full } ;
 
-    KRslots() {}
+    KRslots(QObject *parent): QObject(parent, "KRslots") {}
     ~KRslots() {}
 
   public slots:
@@ -68,6 +68,7 @@ class KRslots : public QObject {
     void configToolbar();
     void configKeys();
     void toggleToolbar();
+	 void toggleActionsToolbar();
     void toggleStatusbar();
     void toggleTerminal();
     void home();
@@ -109,7 +110,6 @@ class KRslots : public QObject {
     void toggleFnkeys();
     void toggleCmdline();
     void changeTrashIcon();
-    void showAboutApplication();
     void multiRename();
     void openRightBookmarks() { RIGHT_PANEL->slotFocusOnMe(); RIGHT_PANEL->bookmarksButton->openPopup(); }
     void openLeftBookmarks() { LEFT_PANEL->slotFocusOnMe(); LEFT_PANEL->bookmarksButton->openPopup(); }
@@ -118,12 +118,12 @@ class KRslots : public QObject {
     void openRightHistory() { RIGHT_PANEL->historyButton->openPopup(); }
 	 void syncPanels() {
 	 	ListPanel *t = ACTIVE_PANEL;
-		OTHER_FUNC->openUrl(ACTIVE_PANEL->virtualPath);
+		OTHER_FUNC->openUrl(ACTIVE_PANEL->virtualPath());
 		t->slotFocusOnMe();
 	 }
     void cmdlinePopup() { MAIN_VIEW->cmdLine->popup(); }
     void duplicateTab();
-    void newTab();
+    void newTab(const KURL& url = KURL());
     void newTab(QListViewItem *item);
     void closeTab();
     void nextTab();
@@ -131,7 +131,9 @@ class KRslots : public QObject {
     void slotSplit();
     void slotCombine();
     void userMenu();
+    void manageUseractions();
     void slotSynchronizeDirs();
+    void slotSyncBrowse();
     void slotDiskUsage();
     void updatePopupPanel(QListViewItem*);
 		void windowActive(); // called when krusader's window becomes focussed
@@ -153,13 +155,15 @@ class KRslots : public QObject {
     // F7
     void mkdir();
     // F8
-    void deleteFiles();
+    void deleteFiles(bool reallyDelete=false);
     // F9
     void rename();
 
     // ugly stubs, remove later ?
     void slotCurrentChanged( QString p ) { MAIN_VIEW->slotCurrentChanged( p ); }
     void slotSetActivePanel( ListPanel *p ) { MAIN_VIEW->slotSetActivePanel( p ); }
+    
+    void jsConsole();
 };
 
 #endif
