@@ -87,6 +87,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "panelmanager.h"
 #include "MountMan/kmountman.h"
 #include "BookMan/krbookmarkhandler.h"
+#include "Dialogs/popularurls.h"
 
 // define the static members
 Krusader *Krusader::App = 0;
@@ -137,7 +138,9 @@ KAction *Krusader::actPreviousTab = 0;
 KAction *Krusader::actSplit = 0;
 KAction *Krusader::actCombine = 0;
 KAction *Krusader::actUserMenu = 0;
+KAction *Krusader::actManageUseractions = 0;
 KAction *Krusader::actSyncDirs = 0;
+KAction *Krusader::actSyncBrowse = 0;
 KAction *Krusader::actF2 = 0;
 KAction *Krusader::actF3 = 0;
 KAction *Krusader::actF4 = 0;
@@ -147,6 +150,7 @@ KAction *Krusader::actF7 = 0;
 KAction *Krusader::actF8 = 0;
 KAction *Krusader::actF9 = 0;
 KAction *Krusader::actF10 = 0;
+KAction *Krusader::actPopularUrls = 0;
 KToggleAction *Krusader::actToggleTerminal = 0;
 KRadioAction  *Krusader::actMarkNewerAndSingle = 0;
 KRadioAction  *Krusader::actMarkSingle = 0;
@@ -155,37 +159,26 @@ KRadioAction  *Krusader::actMarkDifferentAndSingle = 0;
 KRadioAction  *Krusader::actMarkDifferent = 0;
 KRadioAction  **Krusader::compareArray[] = {&actMarkNewerAndSingle, &actMarkNewer, &actMarkSingle, 
                                             &actMarkDifferentAndSingle, &actMarkDifferent, 0};
+KPopupMenu *Krusader::userActionMenu = 0;
 UserAction *Krusader::userAction = 0;
 Expander *Krusader::expander = 0;
 UserMenu *Krusader::userMenu = 0;
 KrBookmarkHandler *Krusader::bookman = 0;
+//QTextOStream *Krusader::_krOut = QTextOStream(::stdout);
+
+#ifdef __KJSEMBED__
+KJSEmbed::KJSEmbedPart *Krusader::js = 0;
+KAction *Krusader::actShowJSConsole = 0;
+#endif
 
 // construct the views, statusbar and menu bars and prepare Krusader to start
 Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
-   // parse command line arguments
+	// parse command line arguments
    KCmdLineArgs * args = KCmdLineArgs::parsedArgs();
-   QString leftPath, rightPath, startProfile;
-
-   // get command-line arguments
-   if ( args->isSet( "left" ) ) {
-      leftPath = args->getOption( "left" );
-      // make sure left or right are not relative paths
-      if ( !leftPath.startsWith( "/" ) && leftPath.find( ":/" ) < 0 )    // make sure we don't touch things like ftp://
-         leftPath = QDir::currentDirPath() + "/" + leftPath;
-   } else leftPath = QString::null;
-   if ( args->isSet( "right" ) ) {
-      rightPath = args->getOption( "right" );
-      // make sure left or right are not relative paths
-      if ( !rightPath.startsWith( "/" ) && rightPath.find( ":/" ) < 0 )    // make sure we don't touch things like ftp://
-         rightPath = QDir::currentDirPath() + "/" + rightPath;
-   } else rightPath = QString::null;
-   if ( args->isSet( "profile" ) ) {
-      startProfile = args->getOption( "profile" );
-   } else startProfile = QString::null;
 
    // create the "krusader"
    App = this;
-   slot = new KRslots();
+   slot = new KRslots(this);
    setXMLFile( "krusaderui.rc" ); // kpart-related xml file
 
    plzWait = new KRPleaseWaitHandler();
@@ -224,6 +217,8 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
    // create bookman
    bookman = new KrBookmarkHandler();
 
+	popularUrls = new PopularUrls(this);
+	
    // create the main view
    mainView = new KrusaderView( this );
    
@@ -236,16 +231,36 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
    // init the protocol handler
    KgProtocols::init();
 
+   krConfig->setGroup( "Startup" );             
+   QStringList l1( krConfig->readPathListEntry( "Left Tab Bar" ) );
+   QStringList l2( krConfig->readPathListEntry( "Right Tab Bar" ) );
+   
+   QString leftPath, rightPath, startProfile;   
+   // get command-line arguments
+   if ( args->isSet( "left" ) ) {
+      leftPath = args->getOption( "left" );
+      // make sure left or right are not relative paths
+      if ( !leftPath.startsWith( "/" ) && leftPath.find( ":/" ) < 0 )    // make sure we don't touch things like ftp://
+         leftPath = QDir::currentDirPath() + "/" + leftPath;
+   } else leftPath = QString::null;
+   if ( args->isSet( "right" ) ) {
+      rightPath = args->getOption( "right" );
+      // make sure left or right are not relative paths
+      if ( !rightPath.startsWith( "/" ) && rightPath.find( ":/" ) < 0 )    // make sure we don't touch things like ftp://
+         rightPath = QDir::currentDirPath() + "/" + rightPath;
+   } else rightPath = QString::null;
+   if ( args->isSet( "profile" ) ) {
+      startProfile = args->getOption( "profile" );
+   } else startProfile = QString::null;
+   
    // starting the panels
    mainView->start( leftPath, rightPath );
 
    // restore TabBar
-   {
-      KConfigGroupSaver grp( krConfig, "Startup" );
-      QStringList l1( krConfig->readPathListEntry( "Left Tab Bar" ) );
-      QStringList l2( krConfig->readPathListEntry( "Right Tab Bar" ) );
+   if (!runKonfig && startProfile.isEmpty() ) {
       QStringList::const_iterator it;
       
+      krConfig->setGroup( "Startup" );             
       if ( krConfig->readEntry( "Left Panel Origin" ) == i18n( "the last place it was" ) )
          for ( it = ++(l1.begin()); it != l1.end(); ++it )
            mainView->leftMng->slotNewTab( *it );
@@ -254,7 +269,7 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
       if ( krConfig->readEntry( "Right Panel Origin" ) == i18n( "the last place it was" ) )
          for ( it = ++(l2.begin()); it != l2.end(); ++it )
            mainView->rightMng->slotNewTab( *it );
-      
+   
       krConfig->setGroup( "Startup" );             
       mainView->leftMng->setActiveTab( krConfig->readNumEntry( "Left Active Tab", 0 ) );
       krConfig->setGroup( "Startup" );             
@@ -270,8 +285,8 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
 
    // create a status bar
    status = new KrusaderStatus( this );
-   QWhatsThis::add( status, i18n( "Status bar will show  basic informations "
-                                     "about file below mouse pointer." ) );
+   QWhatsThis::add( status, i18n( "Statusbar will show basic information "
+                                          "about file below mouse pointer." ) );
 
    // This enables Krusader to show a tray icon
    sysTray = new KSystemTray( this );
@@ -285,21 +300,25 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
    //KAcceleratorManager::manage(this,true);
 
    setCursor( KCursor::arrowCursor() );
-   // first, resize and move to starting point
-   config->setGroup( "Private" );
-   move( oldPos = krConfig->readPointEntry( "Start Position", _StartPosition ) );
-   resize( oldSize = krConfig->readSizeEntry( "Start Size", _StartSize ) );
 
    if ( ! startProfile.isEmpty() )
        mainView->profiles( startProfile );
    
-   if ( krConfig->readBoolEntry( "Maximized" ) )
-      showMaximized();
-   else
-      show();
-
+   if (!runKonfig) {
+		config->setGroup( "Private" );
+		if ( krConfig->readBoolEntry( "Maximized" ) )
+			restoreWindowSize(config);
+		else
+		{
+			// first, resize and move to starting point
+			move( oldPos = krConfig->readPointEntry( "Start Position", _StartPosition ) );
+			resize( oldSize = krConfig->readSizeEntry( "Start Size", _StartSize ) );
+			show();
+		}
+	}
    // let the good times rool :)
    updateGUI( true );
+   
    if ( runKonfig )
       slot->runKonfigurator( true );
 
@@ -309,31 +328,35 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
 Krusader::~Krusader() {}
 
 bool Krusader::versionControl() {
+#define FIRST_RUN	"First Time"
    bool retval = false;
    // create config file
    config = kapp->config();
-   QString oldVerText = config->readEntry( "Version", "200" );
-   oldVerText.truncate( oldVerText.find( "-" ) );
+   bool firstRun = config->readBoolEntry(FIRST_RUN, true);
+
+#if 0      
+	QString oldVerText = config->readEntry( "Version", "10.0" );
+   oldVerText.truncate( oldVerText.findRev( "." ) ); // remove the third dot
    float oldVer = oldVerText.toFloat();
-
-   //kdDebug() << QString( "version = %1" ).arg( oldVer ) << endl;
-
    // older icompatible version
-   if ( oldVer < ( 9 / 10 ) ) {
-      KMessageBox::information( krApp, i18n( "A configuration older then v0.90 was detected Krusader has to reset your configuration to default values. Krusader will now run Konfigurator." ) );
-      if ( !QDir::home().remove( ".kde/share/config/krusaderrc" ) ) {
+   if ( oldVer <= 0.9 ) {
+      KMessageBox::information( krApp, i18n( "A configuration of 1.51 or older was detected. Krusader has to reset your configuration to default values.\nNote: Your bookmarks and keybindings will remain intact.\n Krusader will now run Konfigurator." ) );
+      /*if ( !QDir::home().remove( ".kde/share/config/krusaderrc" ) ) {
          KMessageBox::error( krApp, i18n( "Unable to remove your krusaderrc file! Please remove it manually and rerun Krusader." ) );
          exit( 1 );
-      }
+      }*/
       retval = true;
       config->reparseConfiguration();
    }
+#endif
+
    // first installation of krusader
-   if ( oldVer == 100 ) {
-      KMessageBox::information( krApp, i18n( "Welcome to Krusader, as this is your first run, Krusader will now run Konfigurator." ) );
+   if ( firstRun ) {
+      KMessageBox::information( krApp, i18n( "Welcome to Krusader! As this is your first run, Krusader will now run Konfigurator." ) );
       retval = true;
    }
    config->writeEntry( "Version", VERSION );
+   config->writeEntry( FIRST_RUN, false);
    config->sync();
    return retval;
 }
@@ -383,38 +406,6 @@ void Krusader::setupAccels() {
 	 // SHIFT+F3
    accels->insert( "F3_ViewDlg", i18n( "F3 View Dialog" ), QString::null,
                    SHIFT + Key_F3, SLOTS, SLOT( viewDlg() ) );
-#if 0	
-	// F2
-   accels->insert( "F2_Terminal", i18n( "F2 Terminal" ), QString::null,
-                   Key_F2, SLOTS, SLOT( terminal() ) );
-   // F3
-   accels->insert( "F3_View", i18n( "F3 View" ), QString::null,
-                   Key_F3, SLOTS, SLOT( view() ) );
-   // SHIFT+F3
-   accels->insert( "F3_ViewDlg", i18n( "F3 View Dialog" ), QString::null,
-                   SHIFT + Key_F3, SLOTS, SLOT( viewDlg() ) );
-   // F4
-   accels->insert( "F4_Edit", i18n( "F4 Edit" ), QString::null,
-                   Key_F4, SLOTS, SLOT( edit() ) );
-   // F5
-   accels->insert( "F5_Copy", i18n( "F5 Copy" ), QString::null,
-                   Key_F5, SLOTS, SLOT( copyFiles() ) );
-   // F6
-   accels->insert( "F6_Move", i18n( "F6 Move" ), QString::null,
-                   Key_F6, SLOTS, SLOT( moveFiles() ) );
-   // F7
-   accels->insert( "F7_Mkdir", i18n( "F7 Mkdir" ), QString::null,
-                   Key_F7, SLOTS, SLOT( mkdir() ) );
-   // F8
-   accels->insert( "F8_Delete", i18n( "F8 Delete" ), QString::null,
-                   Key_F8, SLOTS, SLOT( deleteFiles() ) );
-   // F9
-   accels->insert( "F9_Rename", i18n( "F9 Rename" ), QString::null,
-                   Key_F9, SLOTS, SLOT( rename() ) );
-   // F10
-   accels->insert( "F10_Quit", i18n( "F10 Quit" ), QString::null,
-                   Key_F10, this, SLOT( quitKrusader() ) );
-#endif
    // Tab
    accels->insert( "Tab-Switch panel", i18n( "Tab: switch panel" ), QString::null,
                    Key_Tab, mainView, SLOT( panelSwitch() ) );
@@ -437,10 +428,10 @@ void Krusader::setupActions() {
    int compareMode = krConfig->readNumEntry( "Compare Mode", 0 );
    
    KStdAction::home( SLOTS, SLOT( home() ), actionCollection(), "std_home" ); /*->setShortcut(Key_QuoteLeft);*/
-   KAction *actRedisplay = KStdAction::redisplay( SLOTS, SLOT( refresh() ), actionCollection(), "std_redisplay" );
-   actRedisplay->setText( "Reload" );
-   actRedisplay->setShortcut( CTRL + Key_R );
+   new KAction(  i18n( "&Reload" ), "reload", CTRL + Key_R, SLOTS, SLOT( refresh() ), actionCollection(), "std_redisplay" );
    actShowToolBar = KStdAction::showToolbar( SLOTS, SLOT( toggleToolbar() ), actionCollection(), "std_toolbar" );
+	new KToggleAction(i18n("Show Actions Toolbar"), 0, SLOTS, SLOT( toggleActionsToolbar() ),
+		actionCollection(), "toggle actions toolbar");
    actShowStatusBar = KStdAction::showStatusbar( SLOTS, SLOT( toggleStatusbar() ), actionCollection(), "std_statusbar" );
    KStdAction::quit( this, SLOT( quitKrusader() ), actionCollection(), "std_quit" );
    KStdAction::configureToolbars( SLOTS, SLOT( configToolbar() ), actionCollection(), "std_config_toolbar" );
@@ -472,13 +463,13 @@ void Krusader::setupActions() {
                                   SLOT( cmdlinePopup() ), actionCollection(), "cmdline popup" );
    /* Shortcut disabled because of the Terminal Emulator bug. */
    actDirUp = new KAction( i18n( "Up one directory" ), "up", CTRL+Key_PageUp /*Key_Backspace*/, SLOTS, SLOT( dirUp() ), actionCollection(), "dirUp" );
-   new KAction( i18n( "&Edit new file" ), "filenew", SHIFT + Key_F4, SLOTS, SLOT( editDlg() ), actionCollection(), "edit_new_file" );
+   new KAction( i18n( "&Edit New File" ), "filenew", SHIFT + Key_F4, SLOTS, SLOT( editDlg() ), actionCollection(), "edit_new_file" );
    new KAction( i18n( "Start &Root Mode Krusader" ), "krusader_red", ALT + Key_K, SLOTS, SLOT( rootKrusader() ), actionCollection(), "root krusader" );
 
    actTest = new KAction( i18n( "T&est Archive(s)" ), "ark", ALT + Key_E,
                           SLOTS, SLOT( testArchive() ), actionCollection(), "test archives" );
-   actFTPConnect = new KAction( i18n( "&Net Connections" ), "domtreeviewer", 0,
-                                SLOTS, SLOT( runRemoteMan() ), actionCollection(), "ftp connect" );
+   //actFTPConnect = new KAction( i18n( "&Net Connections" ), "domtreeviewer", 0,
+   //                             SLOTS, SLOT( runRemoteMan() ), actionCollection(), "ftp connect" );
    actFTPNewConnect = new KAction( i18n( "New Net &Connection" ), "connect_creating", CTRL + Key_N,
                                    SLOTS, SLOT( newFTPconnection() ), actionCollection(), "ftp new connection" );
    actProfiles = new KAction( i18n( "Pro&files" ), "kr_profile", ALT + Key_L,
@@ -491,9 +482,9 @@ void Krusader::setupActions() {
                           SLOTS, SLOT( slotPack() ), actionCollection(), "pack" );
    actUnpack = new KAction( i18n( "&Unpack" ), "kr_arc_unpack", ALT + Key_U,
                             SLOTS, SLOT( slotUnpack() ), actionCollection() , "unpack" );
-   actSplit = new KAction( i18n( "Sp&lit file" ), "kr_split", CTRL + Key_P,
+   actSplit = new KAction( i18n( "Sp&lit File" ), "kr_split", CTRL + Key_P,
                            SLOTS, SLOT( slotSplit() ), actionCollection(), "split" );
-   actCombine = new KAction( i18n( "Com&bine files" ), "kr_combine", CTRL + Key_B,
+   actCombine = new KAction( i18n( "Com&bine Files" ), "kr_combine", CTRL + Key_B,
                              SLOTS, SLOT( slotCombine() ), actionCollection() , "combine" );
    actSelect = new KAction( i18n( "Select &Group" ), "kr_select", CTRL + Key_Plus,
                             SLOTS, SLOT( markGroup() ), actionCollection(), "select group" );
@@ -540,8 +531,10 @@ void Krusader::setupActions() {
                             SLOTS, SLOT( locate() ), actionCollection(), "locate" );
    actSyncDirs = new KAction( i18n( "Synchronize &Directories" ), "kr_syncdirs", CTRL + Key_Y,
                               SLOTS, SLOT( slotSynchronizeDirs() ), actionCollection(), "sync dirs" );
-   //actDiskUsage = new KAction( i18n( "D&isk Usage" ), "kchart", ALT + Key_D,
-   //                           SLOTS, SLOT( slotDiskUsage() ), actionCollection(), "disk usage" );
+   actSyncBrowse = new KAction( i18n( "S&ynchron directory changes" ), "kr_syncbrowse_off", ALT + Key_Y,
+                              SLOTS, SLOT( slotSyncBrowse() ), actionCollection(), "sync browse" );
+   actDiskUsage = new KAction( i18n( "D&isk Usage" ), "kchart", ALT + Key_D,
+                              SLOTS, SLOT( slotDiskUsage() ), actionCollection(), "disk usage" );
    actInvert = new KAction( i18n( "&Invert Selection" ), "kr_invert", ALT + Key_Asterisk,
                             SLOTS, SLOT( invert() ), actionCollection(), "invert" );
    actUnselect = new KAction( i18n( "&Unselect Group" ), "kr_unselect", CTRL + Key_Minus,
@@ -560,7 +553,7 @@ void Krusader::setupActions() {
    //                             SLOTS, SLOT( execFilter() ), actionCollection(), "exec files" );
    actCustomFilter = new KAction( i18n( "&Custom" ), SHIFT + Key_F12,
                                   SLOTS, SLOT( customFilter() ), actionCollection(), "custom files" );
-   actCompare = new KAction( i18n( "Compare b&y content" ), "kmultiple", 0,
+   actCompare = new KAction( i18n( "Compare b&y Content" ), "kmultiple", 0,
                              SLOTS, SLOT( compareContent() ), actionCollection(), "compare" );
    actMultiRename = new KAction( i18n( "Multi &Rename" ), "krename", SHIFT + Key_F9,
                                  SLOTS, SLOT( multiRename() ), actionCollection(), "multirename" );
@@ -594,13 +587,15 @@ void Krusader::setupActions() {
 	     SLOT( previousTab() ), actionCollection(), "previous tab" );										
    actUserMenu = new KAction( i18n( "User Menu" ), ALT + Key_QuoteLeft, SLOTS,
                               SLOT( userMenu() ), actionCollection(), "user menu" );
+   actManageUseractions = new KAction( i18n( "Manage user actions" ), 0, SLOTS,
+                              SLOT( manageUseractions() ), actionCollection(), "manage useractions" );
 
-	// setup the Fn keys
-	actF2 = new KAction( i18n( "F2 - Open a terminal" ), Key_F2,
+        // setup the Fn keys
+        actF2 = new KAction( i18n( "F2 - Open a terminal" ), Key_F2,
                 SLOTS, SLOT( terminal() ) , actionCollection(), "F2_Terminal" );
-	actF3 = new KAction( i18n( "F3 - View a file" ), Key_F3,
+        actF3 = new KAction( i18n( "F3 - View a file" ), Key_F3,
                 SLOTS, SLOT( view() ) , actionCollection(), "F3_View" );
-	actF4 = new KAction( i18n( "F4 - Edit a file" ), Key_F4,
+        actF4 = new KAction( i18n( "F4 - Edit a file" ), Key_F4,
                 SLOTS, SLOT( edit() ) , actionCollection(), "F4_Edit" );
 	actF5 = new KAction( i18n( "F5 - Copy" ), Key_F5,
                 SLOTS, SLOT( copyFiles() ) , actionCollection(), "F5_Copy" );
@@ -614,11 +609,13 @@ void Krusader::setupActions() {
                 SLOTS, SLOT( rename() ) , actionCollection(), "F9_Rename" );
 	actF10 = new KAction( i18n( "F10 - Quit" ), Key_F10,
                 this, SLOT( quitKrusader() ) , actionCollection(), "F10_Quit" );
+	actPopularUrls = new KAction( i18n("Popular URLs"), CTRL+Key_Z,
+					popularUrls, SLOT( showDialog() ), actionCollection(), "Popular_Urls");
 										
    // and at last we can set the tool-tips
-   actSelect->setToolTip( i18n( "Highlight files by using a filter" ) );
-   actSelectAll->setToolTip( i18n( "Highlight all the files in the current directory" ) );
-   actUnselectAll->setToolTip( i18n( "Remove selection from all highlight files" ) );
+   actSelect->setToolTip( i18n( "Select files using a filter" ) );
+   actSelectAll->setToolTip( i18n("Select all files in the current directory" ) );
+   actUnselectAll->setToolTip( i18n( "Un-select all selected files" ) );
    actKonfigurator->setToolTip( i18n( "Setup Krusader the way you like it" ) );
    actBack->setToolTip( i18n( "Back to the place you came from" ) );
    actRoot->setToolTip( i18n( "ROOT (/)" ) );
@@ -627,6 +624,59 @@ void Krusader::setupActions() {
    // setup all UserActions
    expander = new Expander();
    userAction = new UserAction();
+   
+   #ifdef __KJSEMBED__
+   js = new KJSEmbed::KJSEmbedPart();
+   // make this object, the class Krusader, available for scripting as "Krusader":
+   js->addObject( this, "Krusader" );
+   actBack = new KAction( i18n( "JavaScript console" ), ALT + CTRL + Key_J, SLOTS, SLOT( jsConsole() ), actionCollection(), "JS_Console" );
+   #endif
+}
+
+void Krusader::importKeyboardShortcuts(QString filename) {
+	QFile f(filename);
+	if (!f.open(IO_ReadOnly)) {
+		krOut << "Error opening " << filename << endl;
+		return;
+	}
+	char *actionName;
+	QDataStream stream(&f);
+	int key;
+	KAction *action;
+	while (!stream.atEnd()) {
+		stream >> actionName >> key;
+		action = actionCollection()->action(actionName);
+		if (action) {
+			action->setShortcut(key);
+//			krOut << "set shortcut for " << actionName <<endl;
+		} else {
+		   krOut << "unknown action " << actionName << endl;
+		}
+	}
+	f.close();
+}
+
+void Krusader::exportKeyboardShortcuts(QString filename) {
+	QFile f(filename);
+	if (f.exists() && KMessageBox::warningContinueCancel(this, 
+		i18n("File ")+filename+i18n(" already exists. Are you sure you want to overwrite it?"),
+		i18n("Warning"), i18n("Overwrite")) != KMessageBox::Continue) return;
+	if (!f.open(IO_WriteOnly)) {
+		KMessageBox::error(this, i18n("Error: unable to write to file"), i18n("Error"));
+		return;
+	}
+	QDataStream stream(&f);
+	
+	KAction *action;
+	for (int i=0; i<actionCollection()->count(); ++i) {
+		action = actionCollection()->action(i);
+		int key = action->shortcut().keyCodeQt();
+		if (key) { // if a valid shortcut exists
+			stream << action->name() << key;
+		}
+	}
+	
+	f.close();
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -635,9 +685,13 @@ void Krusader::setupActions() {
 
 void Krusader::savePosition() {
    config->setGroup( "Private" );
-   config->writeEntry( "Start Position", isMaximized() ? oldPos : pos() );
-   config->writeEntry( "Start Size", isMaximized() ? oldSize : size() );
    config->writeEntry( "Maximized", isMaximized() );
+   if (isMaximized())
+      saveWindowSize(config);
+   else {
+      config->writeEntry( "Start Position", isMaximized() ? oldPos : pos() );
+      config->writeEntry( "Start Size", isMaximized() ? oldSize : size() );
+   }
    config->writeEntry( "Panel Size", mainView->vert_splitter->sizes() [ 0 ] );
    config->writeEntry( "Terminal Size", mainView->vert_splitter->sizes() [ 1 ] );
    QValueList<int> lst = mainView->horiz_splitter->sizes();
@@ -650,6 +704,7 @@ void Krusader::savePosition() {
 
 void Krusader::saveSettings() {
    toolBar() ->saveSettings( krConfig, "Private" );
+	toolBar("actionsToolBar")->saveSettings( krConfig, "Actions Toolbar" );
    config->setGroup( "Startup" );
    config->writeEntry( "Left Active Tab", mainView->leftMng->activeTab() );
    config->writeEntry( "Right Active Tab", mainView->rightMng->activeTab() );
@@ -684,6 +739,10 @@ void Krusader::saveSettings() {
       config->writeEntry( "Show Cmd Line", actToggleCmdline->isChecked() );
       config->writeEntry( "Show Terminal Emulator", actToggleTerminal->isChecked() );
    }
+	
+	// save popular links
+	popularUrls->save();
+	
    config->sync();
 }
 
@@ -706,7 +765,7 @@ bool Krusader::queryClose() {
    krConfig->setGroup( "Look&Feel" );
    if ( krConfig->readBoolEntry( "Warn On Exit", _WarnOnExit ) ) {
       switch ( KMessageBox::warningYesNo( this,
-                                          i18n( "Ok to shutdown Krusader?" ) ) ) {
+                                          i18n( "Are you sure you want to quit?" ) ) ) {
             case KMessageBox::Yes :
             quit = true;
             break;
@@ -729,9 +788,8 @@ bool Krusader::queryClose() {
 }
 
 void Krusader::quitKrusader() {
-   if ( queryClose() ) {
-      kapp->quit();
-   }
+   connect( kapp, SIGNAL( lastWindowClosed() ), kapp, SLOT( quit() ) );
+   kapp->closeAllWindows();
 }
 
 // the please wait dialog functions
@@ -769,7 +827,18 @@ void Krusader::updateGUI( bool enforce ) {
 
    // call the XML GUI function to draw the UI
    createGUI( mainView->konsole_part );
+   
+   // this needs to be called AFTER createGUI() !!!
+   userActionMenu = (KPopupMenu*) guiFactory()->container( "useractionmenu", this );
+   if ( userActionMenu )
+      userAction->populateMenu( userActionMenu );
+   
    toolBar() ->applySettings( krConfig, "Private" );
+	
+	toolBar("actionsToolBar") ->applySettings( krConfig, "Actions Toolbar" );
+	static_cast<KToggleAction*>(actionCollection()->action("toggle actions toolbar"))->
+		setChecked(toolBar("actionsToolBar")->isVisible());
+	
    if ( enforce ) {
       // now, hide what need to be hidden
       if ( !krConfig->readBoolEntry( "Show tool bar", _ShowToolBar ) ) {
@@ -803,6 +872,8 @@ void Krusader::updateGUI( bool enforce ) {
          actToggleFnkeys->setChecked( true );
       }
    }
+	// popular urls
+	popularUrls->load();
 }
 
 // return a list in the format of TOOLS,PATH. for example
@@ -817,9 +888,9 @@ QStringList Krusader::supportedTools() {
    QStringList tools;
 
    // first, a diff program: kdiff
-   if ( KrServices::cmdExist( "kdiff" ) ) {
+   if ( KrServices::cmdExist( "kdiff3" ) ) {
       tools.append( "DIFF" );
-      tools.append( KrServices::fullPathName( "kdiff", "diff utility" ) );
+      tools.append( KrServices::fullPathName( "kdiff3", "diff utility" ) );
    } else if ( KrServices::cmdExist( "kompare" ) ) {
       tools.append( "DIFF" );
       tools.append( KrServices::fullPathName( "kompare", "diff utility" ) );
