@@ -45,6 +45,12 @@
 #include <kconfig.h>
 #include <kaccel.h>
 #include <qstringlist.h>
+#include <qtextstream.h>
+#include <kdebug.h>
+
+#ifdef __KJSEMBED__
+#include <kjsembed/kjsembedpart.h>
+#endif
 
 class KrusaderStatus;
 class KRPleaseWaitHandler;
@@ -58,6 +64,10 @@ class UserAction;
 class Expander;
 class KMountMan;
 class KrBookmarkHandler;
+class PopularUrls;
+
+//static QTextOStream krOut(stdout);
+#define krOut kdDebug(50010)
 
 class Krusader : public KParts::MainWindow {
     Q_OBJECT
@@ -66,7 +76,9 @@ class Krusader : public KParts::MainWindow {
     ~Krusader();
     void refreshView();				 // re-create the main view
     static QStringList supportedTools(); // find supported tools
-
+	 void importKeyboardShortcuts(QString filename);
+	 void exportKeyboardShortcuts(QString filename);
+		
   public slots:
     // increase the internal progress bar
     void incProgress( KProcess *, char *buffer, int buflen );
@@ -97,6 +109,7 @@ class Krusader : public KParts::MainWindow {
     KrusaderView *mainView;  // The GUI
     KConfig *config;    // allow everyone to access the config
     KIconLoader *iconLoader; // the app's icon loader
+	 PopularUrls *popularUrls; // holds a sorted list of the most popular urls visited
     // Actions
     static KAction *actProperties, *actPack, *actUnpack, *actTest, *actCompare, *actCmdlinePopup;
     static KAction *actCalculate, *actSelect, *actUnselect, *actSelectAll, *actLocate;
@@ -106,8 +119,9 @@ class Krusader : public KParts::MainWindow {
     static KAction *actKonfigurator, *actToolsSetup, *actBack, *actRoot, *actFind, *actDirUp;
     static KAction *actSelectColorMask, *actMultiRename, *actAllFilter, *actOpenLeftBm, *actOpenRightBm;
     static KAction *actNewTab, *actDupTab, *actCloseTab, *actPreviousTab, *actNextTab, *actSplit; 
-	 static KAction *actCombine, *actUserMenu, *actSyncDirs;
+	 static KAction *actCombine, *actUserMenu, *actManageUseractions, *actSyncDirs, *actSyncBrowse;
 	 static KAction *actF2, *actF3, *actF4, *actF5, *actF6, *actF7, *actF8, *actF9, *actF10;
+	 static KAction *actPopularUrls;
     static KToggleAction *actToggleTerminal;
     static KRadioAction *actMarkNewerAndSingle, *actMarkNewer, *actMarkSingle, 
                         *actMarkDifferentAndSingle, *actMarkDifferent;
@@ -128,11 +142,18 @@ class Krusader : public KParts::MainWindow {
     KrusaderStatus *status;
     KRslots *slot;
     KAccel *accels; // global accelerators
+    
+    static KPopupMenu *userActionMenu;
     static UserMenu *userMenu;
     static UserAction *userAction;
     static Expander *expander;
 	 static KrBookmarkHandler *bookman;
 
+    #ifdef __KJSEMBED__
+    static KJSEmbed::KJSEmbedPart *js;
+    static KAction *actShowJSConsole;
+    #endif
+  
   signals:
     void changeMessage( QString );
 
@@ -152,6 +173,7 @@ class Krusader : public KParts::MainWindow {
 #define krLoader     Krusader::App->iconLoader
 
 #define MAIN_VIEW    (krApp->mainView)
+#define ACTIVE_MNG   (MAIN_VIEW->activeManager())
 #define ACTIVE_PANEL (MAIN_VIEW->activePanel)
 #define ACTIVE_FUNC  (ACTIVE_PANEL->func)
 #define OTHER_PANEL	(ACTIVE_PANEL->otherPanel)
@@ -203,6 +225,7 @@ class Krusader : public KParts::MainWindow {
 #define krSplit           Krusader::App->actSplit
 #define krCombine         Krusader::App->actCombine
 #define krUserMenu        Krusader::App->actUserMenu
+#define krUserActionMenu      Krusader::App->userActionMenu
 #define krUserAction      Krusader::App->userAction
 #define krExpander        Krusader::App->expander
 #define krF2				  Krusader::App->actF2
@@ -214,5 +237,11 @@ class Krusader : public KParts::MainWindow {
 #define krF8				  Krusader::App->actF8
 #define krF9				  Krusader::App->actF9
 #define krF10				  Krusader::App->actF10
+#define krPopularUrls	  Krusader::App->actPopularUrls
+
+#ifdef __KJSEMBED__
+#define krJS			Krusader::App->js
+#define krJSConsole		Krusader::App->actShowJSConsole
+#endif
 
 #endif
