@@ -44,7 +44,7 @@
 #include <klibloader.h> //<>
 #include "GUI/profilemanager.h"
 
-KrusaderView::KrusaderView( QWidget *parent, const char *name ) : QWidget( parent, name ), activePanel(0), 
+KrusaderView::KrusaderView( QWidget *parent ) : QWidget( parent, "KrusaderView" ), activePanel(0), 
 								konsole_part( 0L ) {}
 
 void KrusaderView::start( QString leftPath, QString rightPath ) {
@@ -89,11 +89,18 @@ void KrusaderView::start( QString leftPath, QString rightPath ) {
   // get the last saved sizes of the splitter
   krConfig->setGroup( "Private" );
   QValueList<int> lst = krConfig->readIntListEntry( "Splitter Sizes" );
-  if ( !lst.isEmpty() )
-    horiz_splitter->setSizes( lst );
+  if ( lst.isEmpty() )
+  {
+    lst = horiz_splitter->sizes();
+    int avg = (lst[ 0 ] + lst[ 1 ] )/2;
+    lst[ 0 ] = lst[ 1 ] = avg;
+  }
+  horiz_splitter->setSizes( lst );  
+    
   show();
 
   qApp->processEvents();
+  
   // make the left panel focused at program start
   rightMng->startPanel( right, rightPath );
   leftMng->startPanel( left, leftPath );
@@ -187,9 +194,9 @@ void KrusaderView::savePanelProfiles( QString group )
 {
   krConfig->setGroup( group );
   
-  MAIN_VIEW->leftMng->saveSettings( krConfig, "Left Tabs" );
+  MAIN_VIEW->leftMng->saveSettings( krConfig, "Left Tabs", false );
   krConfig->writeEntry( "Left Active Tab", MAIN_VIEW->leftMng->activeTab() );
-  MAIN_VIEW->rightMng->saveSettings( krConfig, "Right Tabs" );
+  MAIN_VIEW->rightMng->saveSettings( krConfig, "Right Tabs", false );
   krConfig->writeEntry( "Right Active Tab", MAIN_VIEW->rightMng->activeTab() );
   krConfig->writeEntry( "Left Side Is Active", MAIN_VIEW->activePanel->isLeft() );
 }
