@@ -58,7 +58,7 @@ int main(int argc, char *argv[]) {
   KAboutData aboutData( "krusader", ( geteuid() ? I18N_NOOP("Krusader") :
                         I18N_NOOP("Krusader - ROOT PRIVILEGES")),
     VERSION, description, KAboutData::License_GPL,
-    "(c) 2000-2003, Shie Erlich, Rafi Yanai\n(c) 2004, Krusader Krew",
+    "(c) 2000-2003, Shie Erlich, Rafi Yanai\n(c) 2004-2005, Krusader Krew",
     0,
     "http://krusader.sourceforge.net",
     "krusader@users.sourceforge.net");
@@ -69,6 +69,8 @@ int main(int argc, char *argv[]) {
   aboutData.addAuthor("Jonas Baehr", "Developer", "jonas.baehr@web.de", 0);
   aboutData.addAuthor("Dirk Eschler", "Webmaster and i18n coordinator", "deschler@users.sourceforge.net", 0);
   aboutData.addAuthor("Frank Schoolmeesters", "Documentation coordinator", "frank_schoolmeesters@yahoo.com", 0);
+  aboutData.addCredit("The UsefulArts Organization", "Great icon for krusader", "mail@usefularts.rg", 0);
+  aboutData.addCredit("Gábor Lehel", "Viewer module for 3rd Hand", "illissius@gmail.com", 0);
   aboutData.addCredit("Mark Eatough", "Handbook Proof-Reader", "markeatough@yahoo.com", 0);
   aboutData.addCredit("Jan Halasa", "The old Bookmark Module", "xhalasa@fi.muni.cz", 0);
   aboutData.addCredit("Hans Loeffler", "Dir history button", 0, 0);
@@ -97,9 +99,11 @@ int main(int argc, char *argv[]) {
   aboutData.addCredit("Lukasz Janyst","Polish translation","ljan@wp.pl",0);
   aboutData.addCredit("Dmitry Chernyak","Russian translation","chernyak@mail.ru",0);
   aboutData.addCredit("Zdenko Podobna","Slovak translation","zdpo@mailbox.sk",0);
+  aboutData.addCredit("Matej Urbancic","Slovenian translation","matej.urbancic@amis.net",0);
   aboutData.addCredit("Rafael Munoz","Spanish translation","muror@hotpop.com",0);
   aboutData.addCredit("Erik Johanssen","Old Swedish translation","erre@telia.com",0);
-  aboutData.addCredit("Anders Linden","Swedish translation","connyosis@gmx.net",0);
+  aboutData.addCredit("Anders Linden","Old Swedish translation","connyosis@gmx.net",0);
+  aboutData.addCredit("Peter Landgren","Swedish translation","peter.talken@telia.com",0);
   aboutData.addCredit("Ivan Petrouchtchak","Ukrainian translation","connyosis@gmx.net",0);
 
   // Command line arguments ...
